<?xml version="1.0" encoding="UTF-8"?>
<!-- Created by Alessia Cheli, ENEA Bologna, 2007-10-01 -->
<!-- Modified by Cristiano Novelli, ENEA Bologna, 2007-12-11 -->
<xsl:stylesheet version="2.0" xmlns:fo="http://www.w3.org/1999/XSL/Format"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:mm="http://www.moda-ml.org"
	xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:ds="http://www.w3.org/2000/09/xmldsig#"
	xmlns:tp="http://docs.oasis-open.org/ebxmlcppa/cppa-3.0"
	xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/">

	<!-- Template root nel quale viene definito il title del layout a seconda se si tratta di un CPP o CPA. S'importa anche il foglio di stile CSS e le funzioni in JavaScript. Infine si richiama il template BodyLayout che contiene lo sviluppo del layout finale.-->
	<xsl:template match="/">
		<html>
			<head>
				<title>
					<xsl:choose>
						<xsl:when test="tp:CollaborationProtocolProfile"> Layout CPP </xsl:when>
						<xsl:otherwise> Layout CPA </xsl:otherwise>
					</xsl:choose>
				</title>
				<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1"/>
				<style media="all" type="text/css"> @import url(../css/CSS_XSLT_CPPA_2007-10-01.css); </style>
				<script type="text/javascript" language="Javascript" SRC="../js/JS_XSLT_CPPA_2007-10-01.js"/>
			</head>
			<body>
				<xsl:call-template name="BodyLayout"/>
			</body>
		</html>
	</xsl:template>

	<!-- Template BodyLayout contiene lo sviluppo del layout del documento, in quento a partire da esso, vengono richiamati i template principali. Per prima cosa, s'imposta il titolo del documento in base al tipo (CPP o CPA), poi si procede a costruire la tabella contenete le informazioni riguardo allo stesso. La tabella è sezionata in tre parti principali: General CPP/CPA Information, Party Information e Packaging.  -->
	<xsl:template name="BodyLayout">
		<div align="center" class="title">
			<xsl:choose>
				<xsl:when test="tp:CollaborationProtocolProfile"> Collaboration Protocol Profile
					(CPP)<br/><br/>
				</xsl:when>
				<xsl:otherwise> Collaboration Protocol Agreement (CPA)<br/><br/>
				</xsl:otherwise>
			</xsl:choose>
		</div>

		<!-- Prima sezione della tabella: in base al tipo di documento si avrà General CPP Information o General CPA Information. Questo implica il fatto che le informazioni variano a seconda del documento.-->
		<table class="righealterne" align="center"
			title="This section shows general informations about the document.">
			<tr class="sezione pare" id="foldSection1"
				onClick="ApriChiudiClasse('listSection1','foldSection1');">
				<td colspan="4">
					<xsl:choose>
						<xsl:when test="tp:CollaborationProtocolProfile"> General CPP Information </xsl:when>
						<xsl:otherwise> General CPA Information </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>

			<xsl:choose>
				<xsl:when test="tp:CollaborationProtocolProfile">
					<tr class="listSection1" style="display:none"
						title="The unique identifier of the document.">
						<td colspan="2" class="dati">CPP ID:</td>
						<td colspan="2" class="border black">
							<xsl:value-of select="//@cppid"/>
						</td>
					</tr>
				</xsl:when>
				<xsl:otherwise>
					<tr class="listSection1" style="display:none"
						title="The unique identifier of the document, assigned by one Party and used by both.">
						<td colspan="2" class="dati">CPA ID:</td>
						<td colspan="2" class="border black">
							<xsl:value-of select="//@cpaid"/>
						</td>
					</tr>
					<tr class="listSection1" style="display:none"
						title="The state of the process that creates the CPA">
						<td colspan="2" class="dati">Status:</td>
						<td colspan="2" class="border black">
							<xsl:value-of select="//tp:Status/@value"/>
						</td>
					</tr>
					<tr class="listSection1" style="display:none"
						title="The date and time that the CPA goes into effect.">
						<td colspan="2" class="dati">Start:</td>
						<td colspan="2" class="border black">
							<xsl:value-of select="//tp:Start"/>
						</td>
					</tr>				
					<tr class="listSection1" style="display:none"
						title="The date and time after which the CPA MUST be renegotiated by the Parties.">
						<td colspan="2" class="dati">End:</td>
						<td colspan="2" class="border black">
							<xsl:value-of select="//tp:End"/>
						</td>
					</tr>
					<tr class="listSection1" style="display:none"
						title="Concurrent conversations.">
						<td colspan="2" class="dati">Concurrent Conversations:</td>
						<td colspan="2" class="border black">
							<xsl:value-of select="//tp:ConversationConstraints/@concurrentConversations"/>
						</td>
					</tr>	
					<tr class="listSection1" style="display:none"
						title="Invocation Limit.">
						<td colspan="2" class="dati">Invocation Limit:</td>
						<td colspan="2" class="border black">
							<xsl:value-of select="//tp:ConversationConstraints/@invocationLimit"/>
						</td>
					</tr>											
				</xsl:otherwise>
			</xsl:choose>
			<tr class="listSection1" style="display:none">
				<td colspan="2" class="dati">Comment:</td>
				<td colspan="2" class="border black">
					<xsl:value-of select="//tp:Comment"/>
				</td>
			</tr>

			<!-- Seconda sezione della tabella: Party Information, che rappresenta il cuore del documento e che varia, chiareamente, da CPP a CPA. Da qui vengono richiamati i template PartyInfo e Packaging che si occupano, rispettivamente, di descrivere le informazioni relative alle parti coinvolte nelle operazioni di business e di indicare le modalità di impacchettamento dei messaggi che vengono spediti tra esse.-->
			<tr class="sezione pare" id="foldSection2"
				title="In a CPP, this section identifies the organization whose capabilities are described inside the document itself and includes all the details about this Party.
		Moreover, the party can choose to rapresent itself in every single subdivision showing all the different characteristics of everyone (the number written under the party information, shows the number of subdivisions).
		Instead, in a cpa, this section show the partie's agreed term for engaging in the business collaborations.">
				<xsl:choose>
					<xsl:when test="tp:CollaborationProtocolProfile">
						<xsl:attribute name="onClick">
							<xsl:for-each select="//tp:PartyInfo">
									ApriChiudiClasse('foldParty<xsl:number format="1" level="any"
									count="tp:PartyInfo"/>','foldSection2'); </xsl:for-each>
						</xsl:attribute>
						<td colspan="4">Party Information <xsl:if
								test="count(//tp:PartyInfo) &gt; 1">
								<br/>
								<span class="Stile2">(Total Number: <xsl:value-of
										select="count(//tp:PartyInfo)"/>)</span>
							</xsl:if>
						</td>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="onClick"
							>ApriChiudiClasse('listParty1','foldSection2');ApriChiudiClasse('listParty2','foldSection2');ApriChiudiClasse('listParty3','foldSection2');ApriChiudiClasse('listParty4','foldSection2');ApriChiudiClasse('listParty5A','foldSection2');ApriChiudiClasse('listParty5B','foldSection2');ApriChiudiClasse('listParty6','foldSection2');ApriChiudiClasse('listParty7','foldSection2');</xsl:attribute>
						<td colspan="4">Party Information</td>
					</xsl:otherwise>
				</xsl:choose>
			</tr>

			<!-- Si richiama il template che consente di visualizzare tutte le informazioni contenute in PartyInfo-->
			<xsl:choose>
				<xsl:when test="tp:CollaborationProtocolProfile">
					<xsl:apply-templates select="//tp:PartyInfo"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="PartyInfo"/>
				</xsl:otherwise>
			</xsl:choose>

			<!-- Si richiama il template che consente di visualizzare tutte le informazioni contenute in Packaging-->
			<tr class="sezione pare" id="foldSection3"
				onClick="ApriChiudiClasse('listSection3','foldSection3');"
				title="This section shows specific information about how the message header and payload constituent(s) are packaged for transmittal over the transport (encapsulation, constituent parties), including the crucial information about what document-level security packaging is used and the way in which security features have been applied.">
				<td colspan="4">Message Packaging <xsl:if test="count(//tp:Packaging) &gt; 1">
						<br/>
						<span class="Stile2">(Total Number: <xsl:value-of
								select="count(//tp:Packaging)"/>)</span>
					</xsl:if>
				</td>
			</tr>

			<xsl:apply-templates select="//tp:Packaging"/>

		</table>

	</xsl:template>

	<!--********************* INIZIO Sezione PARTY INFORMATION ************************** -->

	<!-- sviluppo party Information cpp/cpa -->
	<!-- Template PartyInfo che fa anche match col nodo tp:PartyInfo, che contiene informazioni relative alle parti coinvolte e richiama i template relativi ai Collaboration Role, Delivery Channel, Transport, Document Exchange e Certificates. Anche in questo caso la visualizzazione delle informazioni si differenzia da CPP a CPA. -->
	<xsl:template match="//tp:PartyInfo" name="PartyInfo">
		<xsl:choose>

			<!-- Se il documento è un CPP -->
			<xsl:when test="ancestor::tp:CollaborationProtocolProfile">
				<xsl:variable name="numPartyInfo">
					<xsl:number level="any"
						from="tp:CollaborationProtocolProfile | tp:CollaborationProtocolAgreement"
						format="1"/>
				</xsl:variable>
				<tr style="display:none" class="partydiv foldParty{$numPartyInfo} pare"
					id="foldParty{$numPartyInfo}"
					title="This subsection identifies the whole organization (or the subdivisions of the organization) whose capabilities are described by the document itself. ">

					<xsl:attribute name="onClick">
						<xsl:for-each select="tp:CollaborationRole">
								ApriChiudiClasse('listParty<xsl:value-of select="$numPartyInfo"
								/><xsl:number format="1" level="single" count="tp:CollaborationRole"
								/>2','foldParty<xsl:value-of select="$numPartyInfo"/>');
						</xsl:for-each> ApriChiudiClasse('listParty<xsl:value-of
							select="$numPartyInfo"/>1','foldParty<xsl:value-of
							select="$numPartyInfo"/>');ApriChiudiClasse('listParty<xsl:value-of
							select="$numPartyInfo"/>3','foldParty<xsl:value-of
							select="$numPartyInfo"/>');ApriChiudiClasse('listParty<xsl:value-of
							select="$numPartyInfo"/>4','foldParty<xsl:value-of
							select="$numPartyInfo"/>');ApriChiudiClasse('listParty<xsl:value-of
							select="$numPartyInfo"/>5','foldParty<xsl:value-of
							select="$numPartyInfo"/>');ApriChiudiClasse('listParty<xsl:value-of
							select="$numPartyInfo"/>6','foldParty<xsl:value-of
							select="$numPartyInfo"/>');ApriChiudiClasse('listParty<xsl:value-of
							select="$numPartyInfo"/>7','foldParty<xsl:value-of
							select="$numPartyInfo"/>'); </xsl:attribute>

					<td colspan="4">
						<xsl:if test="count(tp:PartyInfo) &gt; 1">
							<xsl:number count="tp:PartyInfo" format="1" level="any"/>° </xsl:if>
						Party Information: <xsl:value-of select="@partyName"/>
					</td>
				</tr>
				<tr class="listParty{$numPartyInfo}1" style="display:none">
					<td colspan="2" class="dati">Party Name: </td>
					<td colspan="2" class="black border">
						<strong>
							<xsl:value-of select="@partyName"/>
						</strong>
					</td>
				</tr>
				<tr class="listParty{$numPartyInfo}1" style="display:none">
					<td colspan="2" class="dati">Party ID: </td>
					<td colspan="2" class="border black">
						<xsl:value-of select="tp:PartyId"/>
					</td>
				</tr>
				<xsl:if test="tp:PartyRef">
					<tr class="listParty{$numPartyInfo}1" style="display:none"
						title="Link at the organization reference page where you can find more information about party or the single subdivision.">
						<td colspan="2" class="dati">Party Reference Page: </td>
						<td colspan="2" class="border black">
							<a href="{tp:PartyRef/@xlink:href}">
								<xsl:value-of select="tp:PartyRef/@xlink:href"/>
							</a>
						</td>
					</tr>
				</xsl:if>


				<!-- Si richiama il template relativo allo sviluppo del Collaboration Role per il CPP -->

				<xsl:apply-templates select="tp:CollaborationRole">
					<xsl:with-param name="numParty" select="$numPartyInfo"/>
				</xsl:apply-templates>


				<xsl:if test="./tp:DeliveryChannel">
					<tr class="sottosezione listParty{$numPartyInfo}4 pare"
						id="listParty{$numPartyInfo}4" style="display:none"
						title="This subsection describes the party's message communication characteristics as a combination of trensport and document exchange informations. The document shall contain one or more delivery channel element.">
						<xsl:attribute name="onClick"> ApriChiudiClasse('listSubSection<xsl:value-of
								select="$numPartyInfo"/>4','listParty<xsl:value-of
								select="$numPartyInfo"/>4'); </xsl:attribute>
						<td colspan="4">Delivery Channel <xsl:if
								test="count(tp:DeliveryChannel) &gt; 1">
								<br/>
								<span class="Stile2">(Total Number: <xsl:value-of
										select="count(tp:DeliveryChannel)"/>)</span>
							</xsl:if>
						</td>
					</tr>
				</xsl:if>

				<!-- Si richiama il template relativo allo sviluppo del Delivery Channel per il CPP -->
				<xsl:apply-templates select="tp:DeliveryChannel">
					<xsl:with-param name="numParty" select="$numPartyInfo"/>
				</xsl:apply-templates>

				<xsl:if test="./tp:Transport">
					<tr class="sottosezione listParty{$numPartyInfo}5 pare"
						id="listParty{$numPartyInfo}5" style="display:none"
						title="Thi subsection defines the party's network communication capabilities. One or more transport elements MUST be present in the document, each of which describes a mechanism the Party uses to send messages, a mechanism it uses to receive messages, or both.">
						<xsl:attribute name="onClick"> ApriChiudiClasse('listSubSection<xsl:value-of
								select="$numPartyInfo"/>5','listParty<xsl:value-of
								select="$numPartyInfo"/>5'); </xsl:attribute>
						<td colspan="4">Transport Protocol <xsl:if
								test="count(tp:Transport) &gt; 1">
								<br/>
								<span class="Stile2"> (Total Number: <xsl:value-of
										select="count(tp:Transport)"/>)</span>
							</xsl:if>
						</td>
					</tr>
				</xsl:if>

				<!-- Si richiama il template relativo allo sviluppo del Transport per il CPP-->
				<xsl:apply-templates select="tp:Transport">
					<xsl:with-param name="numParty" select="$numPartyInfo"/>
				</xsl:apply-templates>

				<xsl:if test="./tp:DocExchange">
					<tr class="sottosezione listParty{$numPartyInfo}6 pare"
						id="listParty{$numPartyInfo}6" style="display:none">
						<xsl:attribute name="onClick"> ApriChiudiClasse('listSubSection<xsl:value-of
								select="$numPartyInfo"/>6','listParty<xsl:value-of
								select="$numPartyInfo"/>6'); </xsl:attribute>
						<td colspan="4">Document Exchange <xsl:if
								test="count(tp:DocExchange) &gt; 1">
								<br/>
								<span class="Stile2">(Total Number: <xsl:value-of
										select="count(tp:DocExchange)"/>)</span>
							</xsl:if>
						</td>
					</tr>
				</xsl:if>

				<!-- Si richiama il template relativo allo sviluppo del Document Exchange per il CPP-->
				<xsl:apply-templates select="tp:DocExchange">
					<xsl:with-param name="numParty" select="$numPartyInfo"/>
				</xsl:apply-templates>

				<xsl:if test="./tp:Certificate">
					<tr class="sottosezione listParty{$numPartyInfo}7 pare"
						id="listParty{$numPartyInfo}7" style="display:none">
						<xsl:attribute name="onClick"> ApriChiudiClasse('listSubSection<xsl:value-of
								select="$numPartyInfo"/>7','listParty<xsl:value-of
								select="$numPartyInfo"/>7'); </xsl:attribute>

						<td colspan="4">Certificates <xsl:if test="count(tp:Certificate) &gt; 1">
								<br/>
								<span class="Stile2">(Total Number: <xsl:value-of
										select="count(tp:Certificate)"/>)</span>
							</xsl:if>
						</td>
					</tr>
				</xsl:if>

				<!-- Si richiama il template relativo allo sviluppo del Certificate per il CPP-->
				<xsl:apply-templates select="tp:Certificate">
					<xsl:with-param name="numParty" select="$numPartyInfo"/>
				</xsl:apply-templates>
			</xsl:when>


			<!-- Se il documento è un CPA -->
			<xsl:otherwise>
				<tr class="listParty1" style="display:none">
					<td colspan="2" class="dati">Party Name: </td>
					<td class="black border">
						<strong>
							<xsl:value-of select="//tp:PartyInfo[1]/@partyName"/>
						</strong>
					</td>
					<td class="black border">
						<strong>
							<xsl:value-of select="//tp:PartyInfo[2]/@partyName"/>
						</strong>
					</td>
				</tr>
				<tr class="listParty1" style="display:none">
					<td colspan="2" class="dati">Party ID: </td>
					<td class="black border">
						<xsl:value-of select="//tp:PartyInfo[1]/tp:PartyId"/>
					</td>
					<td class="black border">
						<xsl:value-of select="//tp:PartyInfo[2]/tp:PartyId"/>
					</td>
				</tr>
				<xsl:if test="//tp:PartyInfo[1]/tp:PartyRef | //tp:PartyInfo[2]/tp:PartyRef">
					<tr class="listParty1" style="display:none">
						<td colspan="2" class="dati">Party Reference Page: </td>
						<td class="black border">
							<a href="{//tp:PartyInfo[1]/tp:PartyRef/@xlink:href}">
								<xsl:value-of select="//tp:PartyInfo[1]/tp:PartyRef/@xlink:href"/>
							</a>
						</td>
						<td class="black border">
							<a href="{//tp:PartyInfo[2]/tp:PartyRef/@xlink:href}">
								<xsl:value-of select="//tp:PartyInfo[2]/tp:PartyRef/@xlink:href"/>
							</a>
						</td>
					</tr>
				</xsl:if>

				<!-- Si richiama il template relativo allo sviluppo del Collaboration Role per il CPA-->
				<xsl:for-each select="//tp:PartyInfo[1]/tp:CollaborationRole">
					<xsl:call-template name="CollaborationRole"/>
				</xsl:for-each>

				<xsl:if test="//tp:PartyInfo[1]/tp:DeliveryChannel">
					<tr class="sottosezione listParty4 pare" id="listParty4" style="display:none">
						<xsl:attribute name="onClick">
							ApriChiudiClasse('listSubSection4','listParty4'); </xsl:attribute>
						<td colspan="4">Delivery Channel</td>
					</tr>
				</xsl:if>
				<xsl:for-each select="//tp:PartyInfo[1]/tp:DeliveryChannel">

					<!-- Si richiama il template relativo allo sviluppo del Delivery Channel per il CPA-->
					<xsl:call-template name="DeliveryChannel">
						<xsl:with-param name="numParty">
							<xsl:value-of select="position()"/>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:for-each>

				<xsl:if test="//tp:PartyInfo[1]/tp:Transport">
					<tr class="sottosezione listParty5A pare" id="listParty5A" style="display:none">
						<xsl:attribute name="onClick">
							ApriChiudiClasse('listSubSection5A','listParty5A'); </xsl:attribute>
						<xsl:if test="//tp:PartyInfo[1]//tp:TransportSender">
							<td colspan="4">Transport Protocol - <span class="Stile2">Messages from
										<xsl:value-of select="//tp:PartyInfo[1]/@partyName"/> to
										<xsl:value-of select="//tp:PartyInfo[2]/@partyName"/>
									<xsl:if test="count(//tp:PartyInfo[1]//tp:TransportSender) > 1">
										<br/> (Total Number: <xsl:value-of
											select="count(//tp:PartyInfo[1]//tp:TransportSender)"/>)
									</xsl:if>
								</span>
							</td>
						</xsl:if>
					</tr>
				</xsl:if>

				<xsl:for-each select="//tp:PartyInfo[1]//tp:Transport">

					<!-- Si richiama il template relativo allo sviluppo del Transport per il CPA, nel caso dei messaggi che viaggiano dalla prima parte alla seconda parte. -->
					<xsl:call-template name="Transport">
						<xsl:with-param name="TransportPosition">
							<xsl:value-of select="position()"/>
						</xsl:with-param>
						<xsl:with-param name="TransportSender">1</xsl:with-param>
						<xsl:with-param name="TransportReceiver">2</xsl:with-param>
					</xsl:call-template>
				</xsl:for-each>

				<xsl:if test="//tp:PartyInfo[2]/tp:Transport">
					<tr class="sottosezione listParty5B pare" id="listParty5B" style="display:none">
						<xsl:attribute name="onClick">
							ApriChiudiClasse('listSubSection5B','listParty5B'); </xsl:attribute>
						<xsl:if test="//tp:PartyInfo[2]//tp:TransportSender">
							<td colspan="4">Transport Protocol - <span class="Stile2">Messages from
										<xsl:value-of select="//tp:PartyInfo[2]/@partyName"/> to
										<xsl:value-of select="//tp:PartyInfo[1]/@partyName"/>
									<xsl:if test="count(//tp:PartyInfo[2]//tp:TransportSender) > 1">
										<br/> (Total Number: <xsl:value-of
											select="count(//tp:PartyInfo[2]//tp:TransportSender)"/>)
									</xsl:if>
								</span>
							</td>
						</xsl:if>
					</tr>
				</xsl:if>
				<xsl:for-each select="//tp:PartyInfo[2]/tp:Transport">

					<!-- Si richiama il template relativo allo sviluppo del Transport per il CPA, nel caso dei messaggi che viaggiano dalla seconda parte alla prima parte. -->
					<xsl:call-template name="Transport">
						<xsl:with-param name="TransportPosition">
							<xsl:value-of select="position()"/>
						</xsl:with-param>
						<xsl:with-param name="TransportSender">2</xsl:with-param>
						<xsl:with-param name="TransportReceiver">1</xsl:with-param>
					</xsl:call-template>
				</xsl:for-each>

				<xsl:if test="//tp:PartyInfo[1]/tp:DocExchange">
					<tr class="sottosezione listParty6 pare" id="listParty6" style="display:none"
						title="This subsection provides information that the parties MUST agree on regarding exchange of documents between them. This information includes the messaging service properties (e.g. ebXML Message Service[ebMS])">
						<xsl:attribute name="onClick">
							ApriChiudiClasse('listSubSection6','listParty6'); </xsl:attribute>
						<td colspan="4">Document Exchange</td>
					</tr>
				</xsl:if>

				<xsl:for-each select="//tp:PartyInfo[1]/tp:DocExchange">
					<!-- Si richiama il template relativo allo sviluppo del Document Exchange per il CPA-->
					<xsl:call-template name="DocumentExchange">
						<xsl:with-param name="numParty">
							<xsl:value-of select="position()"/>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:for-each>

				<xsl:if test="//tp:PartyInfo[1]/tp:Certificate">
					<tr class="sottosezione listParty7 pare" id="listParty7" style="display:none"
						title="This subsection defines certificate information for use in this document. One or more certificate elements can be provided for use in the various security functions in the document.">
						<xsl:attribute name="onClick">
							ApriChiudiClasse('listSubSection71','listParty7');ApriChiudiClasse('listSubSection72','listParty7'); </xsl:attribute>
						<td colspan="4">Certificates</td>
					</tr>
				</xsl:if>

				<xsl:for-each select="//tp:PartyInfo">
					<!-- Si richiama il template relativo allo sviluppo del Certificates per il CPA-->
					<xsl:call-template name="Certificates">
						<xsl:with-param name="numParty">
							<xsl:value-of select="position()"/>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<!-- sviluppo collaboration role cpp/cpa-->
	<!-- Template Collaboration Role, consente di visualizzare informazioni relative al ruolo che la parte o le parti assumono nel sigolo processo di business descritto successivamente.
Inoltre, per ogni sottosezione Collaboration Role, vengono indicate le action, ovvero le caratteristiche relative ai messaggi che vengono inviati o ricevuti dalle parti.
Per quanto riguarda i CPP, il numero di collaboration Role vengono visualizzati i collaboration role di ogni parte, per i CPA, invece, viene mostrato il confronto
tra le caratteristiche del collaboration role delle due parti coinvolte.-->
	<xsl:template match="tp:CollaborationRole" name="CollaborationRole">
		<xsl:param name="numParty"/>
		<xsl:variable name="numCollaborationRole">
			<xsl:number level="any" from="tp:PartyInfo" format="1"/>
		</xsl:variable>
		<xsl:choose>

			<!-- Se il documento è un CPP-->
			<xsl:when test="ancestor::tp:CollaborationProtocolProfile">
				<tr class="sottosezione listParty{$numParty}{$numCollaborationRole}2 pare"
					id="listParty{$numParty}{$numCollaborationRole}2" style="display:none"
					title="This subsection identifies the role/roles the party assume in a specifics in business collaboration.">
					<xsl:attribute name="onClick"> ApriChiudiClasse('listSubSection<xsl:value-of
							select="$numParty"/><xsl:value-of select="$numCollaborationRole"
							/>2','listParty<xsl:value-of select="$numParty"/><xsl:value-of
							select="$numCollaborationRole"
							/>2');ApriChiudiClasse('action<xsl:value-of select="$numParty"
							/><xsl:value-of select="$numCollaborationRole"
							/>','listParty<xsl:value-of select="$numParty"/><xsl:value-of
							select="$numCollaborationRole"/>2'); </xsl:attribute>
					<td colspan="4">
						<!-- nel caso il collaboration process sia solo uno, noon viene visualizzato il numero. Qusta tecnica è usata per qualsiasi elemento-sezione visualizzato, che può comparire più volte. -->
						<xsl:choose>
							<xsl:when test="(position()=1) and (position()=last())"> Collaboration
								Process </xsl:when>
							<xsl:otherwise>
								<xsl:number level="any" from="tp:PartyInfo" format="1"/>°
								Collaboration Process </xsl:otherwise>
						</xsl:choose>
					</td>
				</tr>
				<tr class="listSubSection{$numParty}{$numCollaborationRole}2" style="display:none "
					title="It identifies the Business Process-Specification being performed.">
					<td colspan="2" class="dati">Process Specification Name: </td>
					<td class="border black" colspan="2">
						<xsl:value-of select="tp:ProcessSpecification/@name"/>
					</td>
				</tr>
				<tr class="listSubSection{$numParty}{$numCollaborationRole}2" style="display:none "
					title="It uniquely identifies the ProcessSpecification.">
					<td colspan="2" class="dati">Process Specification UUID: </td>
					<td class="border black" colspan="2">
						<xsl:value-of select="tp:ProcessSpecification/@uuid"/>
					</td>
				</tr>
				<tr class="listSubSection{$numParty}{$numCollaborationRole}2" style="display:none "
					title="It identifies which role in the process specification the party is capable of supporting.">
					<td colspan="2" class="dati">Acting Role: </td>
					<td colspan="2" class="border black">
						<xsl:value-of select="tp:Role/@name"/>
					</td>
				</tr>
				<xsl:if test="..//tp:ThisPartyActionBinding">
				<tr class="sottosottosezione action{$numParty}{$numCollaborationRole} pare"
					id="action{$numParty}{$numCollaborationRole}" style="display:none "
					title="This subsection identifies an action message that a party is capable of sending or receiving.">
					<xsl:attribute name="onClick"> ApriChiudiClasse('listSubSubSection<xsl:value-of
							select="$numParty"/><xsl:value-of select="$numCollaborationRole"
							/>','action<xsl:value-of select="$numParty"/><xsl:value-of
							select="$numCollaborationRole"/>'); </xsl:attribute>
					<td colspan="4">Action <xsl:if
							test="count(//tp:PartyInfo[1]//tp:ThisPartyActionBinding) > 1"> (Total
							Number: <xsl:value-of select="count(.//tp:ThisPartyActionBinding)"/>)
						</xsl:if></td>
				</tr>
				</xsl:if>
				<!-- per ogni collaboration role vengono visualizzate le action, richiamando il template -->
				<xsl:apply-templates select=".//tp:ThisPartyActionBinding">
					<xsl:with-param name="numParty" select="$numParty"/>
					<xsl:with-param name="numCollRole" select="$numCollaborationRole"/>
				</xsl:apply-templates>
			</xsl:when>
			<!-- Se il documento è un CPA, si mettono a confronto le caratteristiche delle due parti riferite allo stesso collaboration role -->
			<xsl:otherwise>
				<tr class="sottosezione listParty2 pare" id="listParty2" style="display:none"
					title="This subsection identifies the role/roles the party assume in a specifics in business collaboration.">
					<xsl:attribute name="onClick">
						ApriChiudiClasse('listSubSection2<xsl:value-of select="$numCollaborationRole"/>','listParty2');ApriChiudiClasse('action<xsl:value-of select="$numCollaborationRole"/>','listParty2'); </xsl:attribute>
					<td colspan="4">
						<xsl:choose>
							<xsl:when test="(position()=1) and (position()=last())"> Collaboration
								Process </xsl:when>
							<xsl:otherwise>
								<xsl:number level="any" from="tp:PartyInfo" format="1"/>°
								Collaboration Process </xsl:otherwise>
						</xsl:choose>
					</td>
				</tr>
				<tr class="listSubSection2{$numCollaborationRole}" style="display:none "
					title="It identifies the Business Process-Specification being performed.">
					<td colspan="2" class="dati">Process Specification Name: </td>
					<td class="border black" colspan="2">
						<xsl:value-of
							select="self::node()[$numCollaborationRole]/tp:ProcessSpecification/@name"
						/>
					</td>
				</tr>
				<tr class="listSubSection2{$numCollaborationRole}" style="display:none "
					title="It uniquely identifies the ProcessSpecification.">
					<td colspan="2" class="dati">Process Specification UUID: </td>
					<td class="border black" colspan="2">
						<xsl:value-of
							select="self::node()[$numCollaborationRole]/tp:ProcessSpecification/@uuid"
						/>
					</td>
				</tr>
				<tr class="listSubSection2{$numCollaborationRole}" style="display:none "
					title="It identifies which role in the process specification the party is capable of supporting.">
					<td colspan="2" class="dati">Acting Role: </td>
					<td class="border black">
						<xsl:value-of select="self::node()[$numCollaborationRole]/tp:Role/@name"
						/>
					</td>
					<td class="border black">
						<xsl:value-of select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:CollaborationRole[position()=$numCollaborationRole]/tp:Role/@name"
						/>
					</td>
				</tr>
				<xsl:if test="self::node()[$numCollaborationRole]//tp:ThisPartyActionBinding">
				<tr class="sottosottosezione action{$numCollaborationRole} pare" id="action{$numCollaborationRole}" style="display:none "
					title="This subsection identifies an action message that a party is capable of sending or receiving.">
					<xsl:attribute name="onClick"> ApriChiudiClasse('listSubSubSection<xsl:value-of select="$numCollaborationRole"/>','action<xsl:value-of select="$numCollaborationRole"/>'); </xsl:attribute>
					<td colspan="4">Action <xsl:if
						test="count(self::node()[$numCollaborationRole]//tp:ThisPartyActionBinding) > 1"> (Total
							Number: <xsl:value-of
								select="count(self::node()[$numCollaborationRole]//tp:ThisPartyActionBinding)"/>)
						</xsl:if>
					</td>
				</tr>
				</xsl:if>	
				<!-- Anche qui per ogni collaboration role si visualizza l'elenco delle action richiamando il template apposito. -->
				<xsl:for-each select="self::node()[$numCollaborationRole]//tp:ThisPartyActionBinding">
					<xsl:call-template name="Action">
						<xsl:with-param name="numCollRole"><xsl:value-of select="$numCollaborationRole"/></xsl:with-param>
					</xsl:call-template>
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- sviluppo action cpp/cpa-->
	<!-- Template Action, permette di visualizzare tutte le informazioni relativi ai messaggi che possono essere inviati o ricevuti da una parte aziendale in quel processo di business specificato. -->
	<xsl:template match="tp:ThisPartyActionBinding" name="Action">
		<xsl:param name="numParty"/>
		<xsl:param name="numCollRole"/>
		<xsl:choose>
			<!-- Se il documento è un CPP -->
			<xsl:when test="ancestor::tp:CollaborationProtocolProfile">
				<tr class="listSubSubSection{$numParty}{$numCollRole}" style="display:none "
					title="It identifies the business document exchange to be associated with the delivery channel identified by the channel id.">
					<td width="19%" class="dati" colspan="2">Action Name: </td>
					<td class="border black" colspan="2">
						<xsl:value-of select="@action"/>
					</td>
				</tr>
				<xsl:if test="@id">
					<tr class="listSubSubSection{$numParty}{$numCollRole}" style="display:none ">
						<td class="dati" colspan="2">Action ID: </td>
						<td colspan="2" class="border black">
							<xsl:value-of select="@id"/>
						</td>
					</tr>
				</xsl:if>
				<tr class="listSubSubSection{$numParty}{$numCollRole}" style="display:none ">
					<td class="dati" colspan="2">Sender or Receiver: </td>
					<td colspan="2" class="border black">
						<xsl:choose>
							<xsl:when test="name(..)='tp:CanSend'">Sender</xsl:when>
							<xsl:otherwise>Receiver</xsl:otherwise>
						</xsl:choose>
					</td>
				</tr>
				<tr class="listSubSubSection{$numParty}{$numCollRole}" style="display:none "
					title="It identifies the packaging element to be associated with the message.">
					<td class="dati" colspan="2">Package:</td>
					<td class="border black" colspan="2">
						<a href="#{@packageId}" onclick="ApriAncora('listSection3','foldSection3');">
							<xsl:value-of select="@packageId"/>
						</a>
					</td>
				</tr>
				<xsl:if test=".//tp:ChannelId">
					<tr class="listSubSubSection{$numParty}{$numCollRole}" style="display:none "
						title="It identifies the delivery channel element to be associated with the message.">
						<td class="dati" colspan="2">Delivery Channel ID: </td>
						<td colspan="2" class="border black">
							<a href="#{.//tp:ChannelId}">
								<xsl:attribute name="onClick"
										>ApriAncora('listSubSection<xsl:value-of select="$numParty"
										/>4','listParty<xsl:value-of select="$numParty"/>4');</xsl:attribute>
								<xsl:value-of select=".//tp:ChannelId"/>
							</a>
						</td>
					</tr>
				</xsl:if>
				<xsl:if test="tp:ActionContext">
					<tr class="listSubSubSection{$numParty}{$numCollRole}" style="display:none "
						title="It identifies the binary collaboration for which the action is defined.">
						<td class="dati" colspan="2">Binary Collaboration: </td>
						<td class="border black" colspan="2">
							<xsl:value-of select="@binaryCollaboration"/>
						</td>
					</tr>
				</xsl:if>
				<xsl:if test="mm:ActionContext2 | tp:ActionContext">
					<tr class="listSubSubSection{$numParty}{$numCollRole}" style="display:none "
						title="">
						<td class="dati" colspan="2">Context BTA:</td>
						<td class="border black" colspan="2">
							<xsl:value-of select="mm:ActionContext2/@businessTransactionActivity"/>
							<xsl:value-of select="tp:ActionContext/@businessTransactionActivity"/>
						</td>
					</tr>
				</xsl:if>
				<xsl:if test=".//tp:BusinessTransactionCharacteristics/@*">
					<tr class="listSubSubSection{$numParty}{$numCollRole}" style="display:none "
						title="It describes the security characteristics and other attributes of the delivery channel.">
						<td class="dati" colspan="2">BTA Characteristics: </td>
						<td colspan="2" class="border black">
							<xsl:for-each select=".//tp:BusinessTransactionCharacteristics/@*">
								<em>
									<xsl:value-of select="name()"/>
								</em>: <xsl:value-of select="."/><br/>
							</xsl:for-each>
						</td>
					</tr>
				</xsl:if>
				<tr class="divisorio listSubSubSection{$numParty}{$numCollRole}"
					style="display:none ">
					<xsl:if test="position() != last()">
						<td colspan="4">
							<hr/>
						</td>
					</xsl:if>
				</tr>
			</xsl:when>
			<!-- Se il documento è un CPA -->
			<xsl:otherwise>
				<tr class="listSubSubSection{$numCollRole}" style="display:none "
					title="It identifies the business document exchange to be associated with the delivery channel identified by the channel id.">
					<td width="19%" class="dati" colspan="2">Action Name: </td>
					<td class="border black" colspan="2">
						<strong>
							<xsl:value-of select="@action"/>
						</strong>

					</td>
				</tr>
				<xsl:variable name="action">
					<xsl:value-of select="@action"/>
				</xsl:variable>
				<xsl:variable name="SenderReceiver">
					<xsl:value-of select="name(..)"/>
				</xsl:variable>

				<xsl:if
					test="@id | ancestor::tp:CollaborationProtocolAgreement//tp:PartyInfo[2]/tp:CollaborationRole[position()=$numCollRole]/tp:ThisPartyActionBinding/@id">
					<tr class="listSubSubSection{$numCollRole}" style="display:none ">
						<td class="dati" colspan="2">Action ID: </td>
						<td class="border black">
							<xsl:value-of select="@id"/>
						</td>
						<td class="border black">
							<xsl:for-each
								select="ancestor::tp:CollaborationProtocolAgreement//tp:PartyInfo[2]/tp:CollaborationRole[position()=$numCollRole]/tp:ServiceBinding/*">
								<xsl:if
									test="$action=self::node()//@action and $SenderReceiver!=name() and name()!='tp:Service'">
									<xsl:value-of select="self::node()//@id"/>
								</xsl:if>
							</xsl:for-each>
						</td>
					</tr>
				</xsl:if>

				<tr class="listSubSubSection{$numCollRole}" style="display:none ">
					<td class="dati" colspan="2">Sender or Receiver: </td>
					<xsl:choose>
						<xsl:when test="name(..)='tp:CanSend'">
							<td class="border black">
								<strong>Sender</strong>
							</td>
							<td class="border black">
								<strong>Receiver</strong>
							</td>
						</xsl:when>
						<xsl:otherwise>
							<td class="border black">
								<strong>Receiver</strong>
							</td>
							<td class="border black">
								<strong>Sender</strong>
							</td>
						</xsl:otherwise>
					</xsl:choose>
				</tr>
				<tr class="listSubSubSection{$numCollRole}" style="display:none "
					title="It identifies the packaging element to be associated with the message.">
					<td class="dati" colspan="2">Package:</td>
					<td class="border black">
						<a href="#{@packageId}" onclick="ApriAncora('listSection3','foldSection3');">
							<xsl:value-of select="@packageId"/>
						</a>
					</td>
					<td class="border black">
						<xsl:for-each
							select="ancestor::tp:CollaborationProtocolAgreement//tp:PartyInfo[2]/tp:CollaborationRole[position()=$numCollRole]/tp:ServiceBinding/*">
							<xsl:if
								test="$action=.//@action and $SenderReceiver!=name() and name()!='tp:Service'">
								<a href="#{self::node()//@packageId}"
									onclick="ApriAncora('listSection3','foldSection3');">
									<xsl:value-of select="self::node()//@packageId"/>
								</a>
							</xsl:if>
						</xsl:for-each>
					</td>
				</tr>

				<xsl:if
					test=".//tp:ChannelId | ancestor::tp:CollaborationProtocolAgreement//tp:PartyInfo[2]/tp:CollaborationRole[position()=$numCollRole]/tp:ThisPartyActionBinding//tp:ChannelId">
					<tr class="listSubSubSection{$numCollRole}" style="display:none "
						title="It identifies the delivery channel element to be associated with the message.">
						<td class="dati" colspan="2">Delivery Channel ID: </td>
						<td class="border black">
							<a href="#{self::node()//tp:ChannelId}">
								<xsl:attribute name="onClick"
										>ApriAncora('listSubSection<xsl:value-of select="$numParty"
										/>4','listParty<xsl:value-of select="$numParty"/>4');</xsl:attribute>
								<xsl:value-of select="self::node()//tp:ChannelId"/>
							</a>
						</td>
						<td class="border black">
							<xsl:for-each
								select="ancestor::tp:CollaborationProtocolAgreement//tp:PartyInfo[2]/tp:CollaborationRole[position()=$numCollRole]//tp:ServiceBinding/*">
								<xsl:if
									test="$action=self::node()//@action and $SenderReceiver!=name() and name()!='tp:Service'">
									<a href="#{self::node()//tp:ChannelId}">
										<xsl:attribute name="onClick"
												>ApriAncora('listSubSection<xsl:value-of
												select="$numParty"/>4','listParty<xsl:value-of
												select="$numParty"/>4');</xsl:attribute>
										<xsl:value-of select="self::node()//tp:ChannelId"/>
									</a>
								</xsl:if>
							</xsl:for-each>
						</td>
					</tr>
				</xsl:if>
				<xsl:if
					test="tp:ActionContext | ancestor::tp:CollaborationProtocolAgreement//tp:PartyInfo[2]/tp:CollaborationRole[position()=$numCollRole]/tp:ThisPartyActionBinding/tp:ActionContext">
					<tr class="listSubSubSection{$numCollRole}" style="display:none "
						title="It identifies the binary collaboration for which the action is defined.">
						<td class="dati" colspan="2">Binary Collaboration: </td>
						<td class="border black">
							<xsl:value-of select="@binaryCollaboration"/>
						</td>
						<td class="border black">
							<xsl:for-each
								select="ancestor::tp:CollaborationProtocolAgreement//tp:PartyInfo[2]/tp:CollaborationRole[position()=$numCollRole]/tp:ServiceBinding/*">
								<xsl:if
									test="$action=self::node()//@action and $SenderReceiver!=name() and name()!='tp:Service'">
									<xsl:value-of select="self::node()//@binaryCollaboration"/>
								</xsl:if>
							</xsl:for-each>
						</td>
					</tr>
				</xsl:if>

				<xsl:if
					test="mm:ActionContext2/@businessTransactionActivity | tp:ActionContext/@businessTransactionActivity | ancestor::tp:CollaborationProtocolAgreement//tp:PartyInfo[2]//tp:ThisPartyActionBinding/mm:ActionContext2/@businessTransactionActivity | ancestor::tp:CollaborationProtocolAgreement//tp:PartyInfo[2]//tp:ThisPartyActionBinding/tp:ActionContext/@businessTransactionActivity">
					<tr class="listSubSubSection{$numCollRole}" style="display:none ">
						<td class="dati" colspan="2">Context BTA:</td>
						<td class="border black">
							<xsl:value-of
								select="mm:ActionContext2/@businessTransactionActivity | tp:ActionContext/@businessTransactionActivity"
							/>
						</td>
						<td class="border black">
							<xsl:for-each
								select="ancestor::tp:CollaborationProtocolAgreement//tp:PartyInfo[2]/tp:CollaborationRole[position()=$numCollRole]//tp:ServiceBinding/*">
								<xsl:if
									test="$action=self::node()//@action and $SenderReceiver!=name() and name()!='tp:Service'">
									<xsl:value-of
										select="self::node()//mm:ActionContext2/@businessTransactionActivity | self::node()//tp:ActionContext/@businessTransactionActivity"
									/>
								</xsl:if>
							</xsl:for-each>
						</td>
					</tr>
				</xsl:if>
				<xsl:if
					test=".//tp:BusinessTransactionCharacteristics/@* | ancestor::tp:CollaborationProtocolAgreement//tp:PartyInfo[2]/tp:CollaborationRole[position()=$numCollRole]/tp:ThisPartyActionBinding/tp:BusinessTransactionCharacteristics/@*">
					<tr class="listSubSubSection{$numCollRole}" style="display:none "
						title="It describes the security characteristics and other attributes of the delivery channel.">
						<td class="dati" colspan="2">BTA Characteristics: </td>
						<td class="border black">
							<xsl:for-each select="self::node()//tp:BusinessTransactionCharacteristics/@*">
								<em>
									<xsl:value-of select="name()"/>
								</em>: <xsl:value-of select="."/><br/>
							</xsl:for-each>
						</td>
						<td class="border black">
							<xsl:for-each
								select="ancestor::tp:CollaborationProtocolAgreement//tp:PartyInfo[2]/tp:CollaborationRole[position()=$numCollRole]/tp:ServiceBinding/*">
								<xsl:if
									test="$action=self::node()//@action and $SenderReceiver!=name() and name()!='tp:Service'">
									<xsl:for-each
										select="self::node()//tp:ThisPartyActionBinding/tp:BusinessTransactionCharacteristics/@*">
										<em>
											<xsl:value-of select="name()"/>
										</em>: <xsl:value-of select="."/><br/>
									</xsl:for-each>
								</xsl:if>
							</xsl:for-each>
						</td>
					</tr>
				</xsl:if>
				<tr class="divisorio listSubSubSection{$numCollRole}" style="display:none ">
					<xsl:if test="position() != last()">
						<td colspan="4">
							<hr/>
						</td>
					</xsl:if>
				</tr>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- sviluppo delivery channel cpp/cpa -->
	<!-- Template DeliveryChannel consiste nel visualizzare le informazioni relative al canale di comunicazione usato per l'invio delle informazioni.-->
	<xsl:template match="tp:DeliveryChannel" name="DeliveryChannel">
		<xsl:param name="numParty"/>
		<xsl:variable name="numDel">
			<xsl:number level="any" from="tp:PartyInfo" format="1"/>
		</xsl:variable>
		<xsl:choose>
			<!-- Se il documento è un CPP -->
			<xsl:when test="ancestor::tp:CollaborationProtocolProfile">
				<tr class="listSubSection{$numParty}4" style="display:none ">
					<td class="dati" colspan="2">Delivery Channel ID: </td>
					<td colspan="2" class="border black">
						<a name="{@channelId}">
							<xsl:value-of select="@channelId"/>
						</a>
					</td>
				</tr>
				<tr class="listSubSection{$numParty}4" style="display:none "
					title="The Messaging Characteristics element describes the attributes associated with messages delivered over a given delivery channel. The collaborating parties can stipulate that these attributes be fixed for all messages sent through the delivery channel, or they can agree that these attributes be variable on a “per message” basis.">
					<td class="dati" colspan="2">Messaging Characteristics:</td>
					<td colspan="2" class="border black">
						<xsl:for-each select="./tp:MessagingCharacteristics/@*">
							<em>
								<xsl:value-of select="name()"/>
							</em>: <xsl:value-of select="."/><br/>
						</xsl:for-each>
					</td>
				</tr>
				<tr class="listSubSection{$numParty}4" style="display:none "
					title="It identifies the transport element that defines the transport characteristics of the delivery channel. It MUST have a value that is equal to the value of a transportId attribute of a transport element elsewhere within the document.">
					<td class="dati" colspan="2">Transport ID: </td>
					<td colspan="2" class="border black">
						<a href="#{@transportId}">
							<xsl:attribute name="onClick">ApriAncora('listSubSection<xsl:value-of
									select="$numParty"/>5','listParty<xsl:value-of
									select="$numParty"/>5');</xsl:attribute>
							<xsl:value-of select="@transportId"/>
						</a>
					</td>
				</tr>
				<tr class="listSubSection{$numParty}4" style="display:none "
					title="It identifies the DocExchange element that defines the document-exchange characteristics of the delivery channel. It MUST have a value that is equal to the value of a docExchangeId attribute of a DocExchange element elsewhere within the document.">
					<td class="dati" colspan="2">Document Exchange ID: </td>
					<td colspan="2" class="border black">
						<a href="#{@docExchangeId}">
							<xsl:attribute name="onClick">ApriAncora('listSubSection<xsl:value-of
									select="$numParty"/>6','listParty<xsl:value-of
									select="$numParty"/>6');</xsl:attribute>
							<xsl:value-of select="@docExchangeId"/>
						</a>
					</td>
				</tr>
				<tr class="divisorio listSubSection{$numParty}4" style="display:none ">
					<xsl:if test="position() != last()">
						<td colspan="4">
							<hr/>
						</td>
					</xsl:if>
				</tr>
			</xsl:when>
			<!-- Se il documento è un CPA -->
			<xsl:otherwise>
				<tr class="listSubSection4" style="display:none ">
					<td class="dati" colspan="2">Delivery Channel ID: </td>
					<td class="border black">
						<a name="{@channelId}">
							<xsl:value-of select="@channelId"/>
						</a>
					</td>
					<td class="border black">
						<a
							name="{ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DeliveryChannel[position()=$numDel]/@channelId}">
							<xsl:value-of
								select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DeliveryChannel[position()=$numDel]/@channelId"
							/>
						</a>
					</td>
				</tr>
				<tr class="listSubSection4" style="display:none "
					title="The Messaging Characteristics element describes the attributes associated with messages delivered over a given delivery channel. The collaborating parties can stipulate that these attributes be fixed for all messages sent through the delivery channel, or they can agree that these attributes be variable on a “per message” basis">
					<td class="dati" colspan="2">Messaging Characteristics:</td>
					<td class="border black">
						<xsl:for-each select="./tp:MessagingCharacteristics/@*">
							<em>
								<xsl:value-of select="name()"/>
							</em>: <xsl:value-of select="."/><br/>
						</xsl:for-each>
					</td>
					<td class="border black">
						<xsl:for-each
							select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DeliveryChannel[position()=$numDel]/tp:MessagingCharacteristics/@*">
							<em>
								<xsl:value-of select="name()"/>
							</em>: <xsl:value-of select="."/><br/>
						</xsl:for-each>
					</td>
				</tr>
				<!-- Sia per l'id del protocollo del che del document exchange, viene posto un link "ancora", che consente di collegarsi alla sezione di riferimento per avere maggiori informazioni. -->
				<tr class="listSubSection4" style="display:none "
					title="It identifies the transport element that defines the transport characteristics of the delivery channel. It MUST have a value that is equal to the value of a transportId attribute of a transport element elsewhere within the document.">
					<td class="dati" colspan="2">Transport ID: </td>
					<td class="border black">
						<a href="#{@transportId}">
							<xsl:attribute name="onClick"
								>ApriAncora('listSubSection5B','listParty5B');ApriAncora('listSubSection5A','listParty5A');</xsl:attribute>
							<xsl:value-of select="@transportId"/>
						</a>
					</td>
					<td class="border black">
						<a
							href="#{ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DeliveryChannel[position()=$numDel]/@transportId}">
							<xsl:attribute name="onClick"
								>ApriAncora('listSubSection5B','listParty5B');ApriAncora('listSubSection5A','listParty5A');</xsl:attribute>
							<xsl:value-of
								select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DeliveryChannel[position()=$numDel]/@transportId"
							/>
						</a>
					</td>
				</tr>
				<tr class="listSubSection4" style="display:none "
					title="It identifies the DocExchange element that defines the document-exchange characteristics of the delivery channel. It MUST have a value that is equal to the value of a docExchangeId attribute of a DocExchange element elsewhere within the document.">
					<td class="dati" colspan="2">Document Exchange ID: </td>
					<td class="border black">
						<a href="#{@docExchangeId}">
							<xsl:attribute name="onClick"
								>ApriAncora('listSubSection6','listParty6');</xsl:attribute>
							<xsl:value-of select="@docExchangeId"/>
						</a>
					</td>
					<td class="border black">
						<a
							href="#{ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DeliveryChannel[position()=$numDel]/@docExchangeId}">
							<xsl:attribute name="onClick"
								>ApriAncora('listSubSection6','listParty6');</xsl:attribute>
							<xsl:value-of
								select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DeliveryChannel[position()=$numDel]/@docExchangeId"
							/>
						</a>
					</td>
				</tr>
				<xsl:if test="position() != last()">
					<tr class="divisorio listSubSection4" style="display:none ">
						<td colspan="4">
							<hr/>
						</td>
					</tr>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- sviluppo transport protocol cpp/cpa -->
	<!-- Template Transport, consente di visualizzare le informazioni relative al trasporto dei messaggi.
Nel CPP è presente un'unica sezione relativa al trasporto, nel quale vengono visualizzate le tipologie diverse di trasporto per ogni parte.
Nel CPA, invece vengono visualizzate due sezioni: la prima iassume i trasporti che avvengono tra la prima e la seconda parte, la seconda, il caso contrario. -->
	<xsl:template match="tp:Transport" name="Transport">
		<xsl:param name="numParty"/>
		<xsl:param name="TransportPosition"/>
		<xsl:param name="TransportSender"/>
		<xsl:param name="TransportReceiver"/>
		<xsl:choose>
			<!-- Se il documento è un CPP -->
			<xsl:when test="ancestor::tp:CollaborationProtocolProfile">
				<tr class="listSubSection{$numParty}5" style="display:none ">
					<td class="dati" colspan="2">Transport Protocol ID: </td>
					<td colspan="2" class="border black">
						<a name="{@transportId}">
							<xsl:value-of select="@transportId"/>
						</a>
					</td>
				</tr>
				<xsl:choose>
					<xsl:when test="count(child::*)=2">
						<xsl:call-template name="SenderANDReceiver">
							<xsl:with-param name="numParty" select="$numParty"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="SenderORReceiver">
							<xsl:with-param name="numParty" select="$numParty"/>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
				<tr class="divisorio listSubSection{$numParty}5" style="display:none;">
					<xsl:if test="position() != last()">
						<td colspan="4">
							<hr/>
						</td>
					</xsl:if>
				</tr>
			</xsl:when>
			<!-- Se il documento è un CPA -->
			<xsl:otherwise>
				<xsl:choose>
					<!-- Si visualizzano tutti i dati dei trasporti che hanno come emittente la prima parte -->
					<xsl:when test="$TransportSender=1">
						<tr class="listSubSection5A" style="display:none ">
							<td class="dati" colspan="2">Transport Protocol ID: </td>
							<td class="border black">
								<a name="{current()[$TransportPosition]/@transportId}">
									<xsl:value-of
										select="current()[$TransportPosition]/@transportId"/>
								</a>
							</td>
							<td class="border black">
								<a
									name="{ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:Transport[position()=$TransportPosition]/@transportId}">
									<xsl:value-of
										select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:Transport[position()=$TransportPosition]/@transportId"
									/>
								</a>
							</td>
						</tr>

						<tr class="listSubSection5A" style="display:none "
							title="It indicates if transport can be used to send or(and) receive messages.">
							<td class="dati" colspan="2">Party's Role: </td>
							<td class="border black">
								<strong>Sender</strong>
							</td>
							<td class="border black">
								<strong>Receiver</strong>
							</td>
						</tr>
						<tr class="listSubSection5A" style="display:none "
							title="It identifies a transport protocol that the party is capable of using to send or receive Business data.">
							<td class="dati" colspan="2">Transport Protocol: </td>
							<td class="border black">
								<xsl:value-of
									select="current()[position()=$TransportPosition]/tp:TransportSender/tp:TransportProtocol"
								/>
							</td>
							<td class="border black">
								<xsl:value-of
									select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver/tp:TransportProtocol"
								/>
							</td>
						</tr>
						<xsl:if
							test="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver/tp:Endpoint/@uri">
							<tr class="listSubSection5A" style="display:none "
								title="It specifies logical addresses where messages can be received.">
								<td class="dati" colspan="2">Endpoint Address: </td>
								<td class="border black">---</td>
								<td class="border black">
									<xsl:choose>
										<xsl:when
											test="contains(ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver/tp:Endpoint/@uri,'@')">
											<a
												href="mailto:{ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver/tp:Endpoint/@uri}">
												<xsl:value-of
												select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver/tp:Endpoint/@uri"
												/>
											</a>

										</xsl:when>
										<xsl:otherwise>
											<a
												href="{ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver/tp:Endpoint/@uri}">
												<xsl:value-of
												select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver/tp:Endpoint/@uri"
												/>
											</a>

										</xsl:otherwise>
									</xsl:choose>


								</td>
							</tr>
						</xsl:if>

						<xsl:if
							test="current()[position()=$TransportPosition]/tp:TransportSender//tp:TransportSecurityProtocol | ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver//tp:TransportSecurityProtocol">
							<tr class="listSubSection5A" style="display:none "
								title="It provides information about a secure connection established between client and server.">
								<td class="dati" colspan="2">Transport Security Protocol: </td>
								<td class="border black">
									<xsl:value-of
										select="current()[position()=$TransportPosition]/tp:TransportSender//tp:TransportSecurityProtocol"
									/>
								</td>
								<td class="border black">
									<xsl:value-of
										select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver//tp:TransportSecurityProtocol"
									/>
								</td>
							</tr>
						</xsl:if>
						<xsl:if
							test="current()[position()=$TransportPosition]/tp:TransportSender//@certId | ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver//@certId">
							<tr class="listSubSection5A" style="display:none "
								title="It identifies the certificate to be used by the transport security module. The certificate is a reference to the certificate id element that has the matching ID attribute value.">
								<td class="dati" colspan="2">Transport Security Certificates: </td>
								<td class="border black">
									<xsl:value-of
										select="current()[position()=$TransportPosition]/tp:TransportSender//@certId"
									/>
								</td>
								<td class="border black">
									<xsl:value-of
										select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver//@certId"
									/>
								</td>
							</tr>
						</xsl:if>
						<tr class="divisorio listSubSection5A" style="display:none;">
							<xsl:if test="position() != last()">
								<td colspan="4">
									<hr/>
								</td>
							</xsl:if>
						</tr>
					</xsl:when>
					<!-- Si visualizzano tutti i dati dei trasporti che hanno come emittente la seconda parte -->
					<xsl:otherwise>
						<tr class="listSubSection5B" style="display:none ">
							<td class="dati" colspan="2">Transport Protocol ID: </td>
							<td class="border black">
								<a
									name="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[1]/tp:Transport[position()=$TransportPosition]/@transportId">
									<xsl:value-of
										select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[1]/tp:Transport[position()=$TransportPosition]/@transportId"
									/>
								</a>
							</td>
							<td class="border black">
								<a name="current()[position()=$TransportPosition]/@transportId">
									<xsl:value-of
										select="current()[$TransportPosition]/@transportId"/>
								</a>
							</td>
						</tr>

						<tr class="listSubSection5B" style="display:none "
							title="It indicates if transport can be used to send or(and) receive messages.">
							<td class="dati" colspan="2">Party's Role: </td>
							<td class="border black">
								<strong>Receiver</strong>
							</td>
							<td class="border black">
								<strong>Sender</strong>
							</td>
						</tr>
						<tr class="listSubSection5B" style="display:none "
							title="It identifies a transport protocol that the party is capable of using to send or receive business data.">
							<td class="dati" colspan="2">Transport Protocol: </td>
							<td class="border black">
								<xsl:value-of
									select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[1]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver/tp:TransportProtocol"
								/>
							</td>
							<td class="border black">
								<xsl:value-of
									select="current()[position()=$TransportPosition]/tp:TransportSender/tp:TransportProtocol"
								/>
							</td>
						</tr>
						<xsl:if
							test="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[1]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver/tp:Endpoint/@uri">
							<tr class="listSubSection5B" style="display:none "
								title="It specifies logical addresses where messages can be received.">
								<td class="dati" colspan="2">Endpoint Address: </td>
								<td class="border black">
									<xsl:choose>
										<xsl:when
											test="contains(ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[1]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver/tp:Endpoint/@uri,'@')">
											<a
												href="mailto:{ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[1]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver/tp:Endpoint/@uri}">
												<xsl:value-of
												select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[1]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver/tp:Endpoint/@uri"
												/>
											</a>

										</xsl:when>
										<xsl:otherwise>
											<a
												href="{ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[1]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver/tp:Endpoint/@uri}">
												<xsl:value-of
												select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[1]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver/tp:Endpoint/@uri"
												/>
											</a>

										</xsl:otherwise>
									</xsl:choose>

								</td>
								<td class="border black">---</td>
							</tr>
						</xsl:if>

						<xsl:if
							test="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[1]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver//tp:TransportSecurityProtocol | current()[position()=$TransportPosition]/tp:TransportSender//tp:TransportSecurityProtocol">
							<tr class="listSubSection5B" style="display:none "
								title="It provides information about a secure connection established between client and server.">
								<td class="dati" colspan="2">Transport Security Protocol: </td>
								<td class="border black">
									<xsl:value-of
										select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[1]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver//tp:TransportSecurityProtocol"
									/>
								</td>
								<td class="border black">
									<xsl:value-of
										select="current()[position()=$TransportPosition]/tp:TransportSender//tp:TransportSecurityProtocol"
									/>
								</td>
							</tr>
						</xsl:if>
						<xsl:if
							test="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[1]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver//@certId | current()[position()=$TransportPosition]/tp:TransportSender//@certId">
							<tr class="listSubSection5B" style="display:none "
								title="It identifies the certificate to be used by the transport security module. The certificate is a reference to the certificate id element that has the matching ID attribute value.">
								<td class="dati" colspan="2">Transport Security Certificates: </td>
								<td class="border black">
									<xsl:value-of
										select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[1]/tp:Transport[position()=$TransportPosition]/tp:TransportReceiver//@certId"
									/>
								</td>
								<td class="border black">
									<xsl:value-of
										select="current()[position()=$TransportPosition]/tp:TransportSender//@certId"
									/>
								</td>
							</tr>
						</xsl:if>
						<tr class="divisorio listSubSection5B" style="display:none;">
							<xsl:if test="position() != last()">
								<td colspan="4">
									<hr/>
								</td>
							</xsl:if>
						</tr>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- sviluppo SenderANDReceiver Transport Protocol cpp-->
	<!-- Questo template fa riferimento al template transport ed è relativo solo al CPP. Si applica quando una parte fa sia da sender che da receiver per quelo specifico trasporto.-->
	<xsl:template name="SenderANDReceiver">
		<xsl:param name="numParty"/>
		<tr class="listSubSection{$numParty}5" style="display:none "
			title="It indicates if transport can be used to send and receive messages.">
			<td class="dati" colspan="2">Party's Role</td>
			<td width="38%" class="black border">
				<strong>Sender</strong>
			</td>
			<td width="37%" class="black border">
				<strong>Receiver</strong>
			</td>
		</tr>
		<tr class="listSubSection{$numParty}5" style="display:none "
			title="It identifies a transport protocol that the party is capable of using to send or receive business data.">
			<td class="dati" colspan="2">Transport Protocol: </td>
			<td class="border black">
				<xsl:value-of select="tp:TransportSender/tp:TransportProtocol"/>
			</td>
			<td class="border black">
				<xsl:value-of select="tp:TransportReceiver/tp:TransportProtocol"/>
			</td>
		</tr>
		<xsl:if test="tp:TransportReceiver/tp:Endpoint/@uri">
			<tr class="listSubSection{$numParty}5" style="display:none "
				title="It specifies logical addresses where messages can be received.">
				<td class="dati" colspan="2">Endpoint Address: </td>
				<td class="border black">---</td>
				<td class="border black">
					<xsl:choose>
						<xsl:when test="contains(tp:TransportReceiver/tp:Endpoint/@uri,'@')">
							<a href="mailto:{tp:TransportReceiver/tp:Endpoint/@uri}">
								<xsl:value-of select="tp:TransportReceiver/tp:Endpoint/@uri"/>
							</a>

						</xsl:when>
						<xsl:otherwise>
							<a href="{tp:TransportReceiver/tp:Endpoint/@uri}">
								<xsl:value-of select="tp:TransportReceiver/tp:Endpoint/@uri"/>
							</a>

						</xsl:otherwise>
					</xsl:choose>

				</td>
			</tr>
		</xsl:if>
		<xsl:if
			test="tp:TransportSender//tp:TransportSecurityProtocol | tp:TransportReceiver//tp:TransportSecurityProtocol">
			<tr class="listSubSection{$numParty}5" style="display:none "
				title="It provides information about a secure connection established between client and server.">
				<td class="dati" colspan="2">Transport Security Protocol: </td>
				<td class="border black">
					<xsl:value-of select="tp:TransportSender//tp:TransportSecurityProtocol"/>
				</td>
				<td class="border black">
					<xsl:value-of select="tp:TransportReceiver//tp:TransportSecurityProtocol"/>
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="tp:TransportSender//@certId | tp:TransportReceiver//@certId">
			<tr class="listSubSection{$numParty}5" style="display:none "
				title="It identifies the certificate to be used by the transport security module. The certificate is a reference to the certificate id element that has the matching ID attribute value.">
				<td class="dati" colspan="2"> Transport Security Certificates: </td>
				<td class="border black">
					<xsl:value-of select="tp:TransportSender//@certId"/>
				</td>
				<td class="border black">
					<xsl:value-of select="tp:TransportReceiver//@certId"/>
				</td>
			</tr>
		</xsl:if>
	</xsl:template>

	<!-- sviluppo SenderORReceiver Transport Protocol cpp-->
	<!-- Questo template fa riferimento al template transport ed è relativo solo al CPP. Si applica quando una parte fa da sender o da receiver per quelo specifico trasporto.-->
	<xsl:template name="SenderORReceiver">
		<xsl:param name="numParty"/>
		<tr class="listSubSection{$numParty}5" style="display:none "
			title="It indicates if transport can be used to send or receive messages.">
			<td class="dati" colspan="2">Party's Role</td>
			<td class="border black" colspan="2">
				<strong>
					<xsl:choose>
						<xsl:when test="name()='tp:TransportSender'"> Sender </xsl:when>
						<xsl:otherwise> Receiver </xsl:otherwise>
					</xsl:choose>
				</strong>
			</td>
		</tr>
		<tr class="listSubSection{$numParty}5" style="display:none "
			title="It identifies a transport protocol that the party is capable of using to send or receive business data.">
			<td class="dati" colspan="2">Transport Protocol: </td>
			<td class="border black" colspan="2">
				<xsl:value-of select=".//tp:TransportProtocol"/>
			</td>
		</tr>
		<xsl:if test=".//tp:Endpoint/@uri">
			<tr class="listSubSection{$numParty}5" style="display:none "
				title="It specifies logical addresses where messages can be received.">
				<xsl:if test="name()!='tp:TransportSender'">
					<td class="dati" colspan="2">Endpoint Address: </td>
					<td class="border black" colspan="2">
						<xsl:choose>
							<xsl:when test="contains(.//tp:Endpoint/@uri,'@')">
								<a href="mailto:{.//tp:Endpoint/@uri}">
									<xsl:value-of select=".//tp:Endpoint/@uri"/>
								</a>
							</xsl:when>
							<xsl:otherwise>
								<a href="{.//tp:Endpoint/@uri}">
									<xsl:value-of select=".//tp:Endpoint/@uri"/>
								</a>
							</xsl:otherwise>
						</xsl:choose>

					</td>
				</xsl:if>
			</tr>
		</xsl:if>
		<xsl:if
			test="tp:TransportSender//tp:TransportSecurityProtocol | tp:TransportReceiver//tp:TransportSecurityProtocol">
			<tr class="listSubSection{$numParty}5" style="display:none "
				title="It provides information about a secure connection established between client and server.">
				<td class="dati" colspan="2">Transport Security Protocol: </td>
				<td class="border black" colspan="2">
					<xsl:value-of select="tp:TransportSender//tp:TransportSecurityProtocol"/>
					<xsl:value-of select="tp:TransportReceiver//tp:TransportSecurityProtocol"/>
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="tp:TransportSender//@certId | tp:TransportReceiver//@certId">
			<tr class="listSubSection{$numParty}5" style="display:none "
				title="It identifies the certificate to be used by the transport security module. The certificate is a reference to the certificate id element that has the matching ID attribute value.">
				<td class="dati" colspan="2"> Transport Security Certificates: </td>
				<td class="border black" colspan="2">
					<xsl:value-of select="tp:TransportSender//@certId"/>
					<xsl:value-of select="tp:TransportReceiver//@certId"/>
				</td>
			</tr>
		</xsl:if>
	</xsl:template>

	<!-- sviluppo document exchange cpp/cpa -->
	<!-- Template Document Exchange, si occupa di visualizzare le informazioni relative allo scambio dei documenti. -->
	<xsl:template match="tp:DocExchange" name="DocumentExchange">
		<xsl:param name="numParty"/>
		<xsl:variable name="Child">1</xsl:variable>

		<xsl:choose>
			<!-- Se il documento è un CPP -->
			<xsl:when test="ancestor::tp:CollaborationProtocolProfile">
				<tr class="listSubSection{$numParty}6" style="display:none ">
					<td class="dati" colspan="2">Document Exchange ID: </td>
					<td colspan="2" class="border black">
						<a name="{@docExchangeId}">
							<xsl:value-of select="@docExchangeId"/>
						</a>
					</td>
				</tr>
				<tr class="listSubSection{$numParty}6" style="display:none "
					title="It defines if the party can send and(or) receive messages.">
					<td class="dati" colspan="2">Exchange Role: </td>
					<xsl:call-template name="DocExchangeDevelope_Ipart">
						<xsl:with-param name="DocExchangeChild" select="$Child"/>
					</xsl:call-template>
				</tr>
				<tr class="listSubSection{$numParty}6" style="display:none "
					title="It shows which is the message services used for exchanging messages (es. ebXML Message Service).">
					<td class="dati" colspan="2">Messaging Protocol: </td>
					<!-- Richiama il template DocExchangeDevelope_Ipart -->
					<xsl:call-template name="DocExchangeDevelope_Ipart">
						<xsl:with-param name="DocExchangeChild" select="$Child+1"/>
					</xsl:call-template>
				</tr>
				<xsl:choose>
					<xsl:when
						test="count(tp:ebXMLSenderBinding/child::*) &gt; 0 or count(tp:ebXMLReceiverBinding/child::*) &gt; 0 or count(tp:WSSenderBinding/child::*) &gt; 0 or count(tp:WSReceiverBinding/child::*) &gt; 0">
						<!-- Richiama il template DocExchangeDevelope_IIpart -->
						<xsl:call-template name="DocExchangeDevelope_IIpart">
							<xsl:with-param name="numParty" select="$numParty"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<tr class="divisorio listSubSection{$numParty}6" style="display:none;">
							<xsl:if test="position() != last()">
								<td colspan="4">
									<hr/>
								</td>
							</xsl:if>
						</tr>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<!-- Se il documento è un CPA -->
			<xsl:otherwise>
				<tr class="listSubSection6" style="display:none ">
					<td class="dati" colspan="2">Document Exchange ID: </td>
					<td class="border black">
						<a name="{@docExchangeId}">
							<xsl:value-of select="@docExchangeId"/>
						</a>
					</td>
					<td class="border black">
						<a
							name="{ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange/@docExchangeId}">
							<xsl:value-of
								select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange/@docExchangeId"
							/>
						</a>
					</td>
				</tr>
				<tr class="listSubSection6" style="display:none "
					title="It defines if the party can send and(or) receive messages.">
					<td class="dati" colspan="2">Exchange Role: </td>
					<xsl:call-template name="DocExchangeDevelope_Ipart">
						<xsl:with-param name="DocExchangeChild" select="$Child"/>
					</xsl:call-template>
				</tr>
				<tr class="listSubSection6" style="display:none "
					title="It shows which is the message services used for exchanging messages (es. ebXML Message Service).">
					<td class="dati" colspan="2">Messaging Protocol: </td>
					<!-- Richiama il template DocExchangeDevelope_Ipart -->
					<xsl:call-template name="DocExchangeDevelope_Ipart">
						<xsl:with-param name="DocExchangeChild" select="$Child+1"/>
					</xsl:call-template>
				</tr>
				<xsl:choose>
					<xsl:when
						test="count(tp:ebXMLSenderBinding/child::*) &gt; 0 or count(tp:ebXMLReceiverBinding/child::*) &gt; 0 or count(tp:WSSenderBinding/child::*) &gt; 0 or count(tp:WSReceiverBinding/child::*) &gt; 0 or count(ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange/tp:ebXMLSenderBinding/child::*) &gt; 0 or count(ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange/tp:ebXMLReceiverBinding/child::*) &gt; 0 or count(ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange/tp:WSSenderBinding/child::*) &gt; 0 or count(ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange/tp:WSReceiverBinding/child::*) &gt; 0">
						<!-- Richiama il template DocExchangeDevelope_IIpart -->
						<xsl:call-template name="DocExchangeDevelope_IIpart"/>
					</xsl:when>
					<xsl:otherwise>
						<tr class="divisorio listSubSection6" style="display:none;">
							<xsl:if test="position() != last()">
								<td colspan="4">
									<hr/>
								</td>
							</xsl:if>
						</tr>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- sviluppo DocExchangeDevelope_Ipart cpp/cpa-->
	<!-- Template DocExchangeDevelope_Ipart, stabilisce sia per CPP e CPA, il ruolo che ogni parte coinvolta ha nello scambio e il protocollo-->
	<xsl:template name="DocExchangeDevelope_Ipart">
		<xsl:param name="DocExchangeChild"/>
		<xsl:variable name="numDoc">
			<xsl:number level="any" from="tp:PartyInfo" format="1"/>
		</xsl:variable>
		<xsl:choose>
			<!-- Se il documento è un CPP -->
			<xsl:when test="ancestor::tp:CollaborationProtocolProfile">
				<xsl:for-each select="child::*">
					<xsl:choose>
						<xsl:when test="$DocExchangeChild=1">
							<!-- Exchange Role -->
							<xsl:choose>
								<xsl:when test="contains(name(),'Sender')">
									<td class="black border">
										<strong>Sender</strong>
									</td>
								</xsl:when>
								<xsl:otherwise>
									<td class="black border">
										<strong>Receiver</strong>
									</td>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:otherwise>
							<!-- Message Protocol -->
							<td class="border black">
								<xsl:value-of
									select="substring-before(substring-after(name(),'tp:'),'SenderBinding')"/>
								<xsl:value-of
									select="substring-before(substring-after(name(),'tp:'),'ReceiverBinding')"
								/>
							</td>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
			</xsl:when>
			<!-- Se il documento è un CPA. -->
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="$DocExchangeChild=1">
						<!-- Exchange Role -->
						<td class="black border">
							<strong>
								<xsl:for-each select="child::*">
									<xsl:choose>
										<xsl:when test="contains(name(),'Sender')"> Sender <br/>
										</xsl:when>
										<xsl:otherwise> Receiver </xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</strong>
						</td>
						<td class="black border">
							<strong>
								<xsl:for-each
									select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]/*">
									<xsl:choose>
										<xsl:when test="contains(name(),'Sender')"> Sender <br/>
										</xsl:when>
										<xsl:otherwise> Receiver </xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</strong>
						</td>
					</xsl:when>
					<xsl:otherwise>
						<!-- Message Protocol -->
						<td class="black border">
							<xsl:for-each select="child::*">
								<xsl:choose>
									<xsl:when test="contains(name(),'SenderBinding')">
										<em>Sender: </em>
										<xsl:value-of
											select="substring-before(substring-after(name(),'tp:'),'SenderBinding')"/>
										<br/>
									</xsl:when>
									<xsl:otherwise>
										<em>Receiver: </em>
										<xsl:value-of
											select="substring-before(substring-after(name(),'tp:'),'ReceiverBinding')"
										/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:for-each>
						</td>

						<td class="black border">
							<xsl:for-each
								select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]/*">
								<xsl:choose>
									<xsl:when test="contains(name(),'SenderBinding')">
										<em>Sender: </em>
										<xsl:value-of
											select="substring-before(substring-after(name(),'tp:'),'SenderBinding')"/>
										<br/>
									</xsl:when>
									<xsl:otherwise>
										<em>Receiver: </em>
										<xsl:value-of
											select="substring-before(substring-after(name(),'tp:'),'ReceiverBinding')"
										/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:for-each>
						</td>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- sviluppo DocExchangeDevelope_IIpart cpp/cpa-->
	<!-- Template DocExchangeDevelope_IIpart, permette di visualizzare tutte le restanti informazioni relative alle parti, per quel che riguarda il document exchange.
 Da notare che è stata implementata anche la parte relativa ai Web Services.-->
	<xsl:template name="DocExchangeDevelope_IIpart">
		<xsl:param name="numParty"/>
		<xsl:variable name="numDoc">
			<xsl:number level="any" from="tp:PartyInfo" format="1"/>
		</xsl:variable>
		<xsl:choose>
			<!-- Se il documento è un CPA-->
			<xsl:when test="ancestor::tp:CollaborationProtocolAgreement">
				<xsl:for-each select="*">
					<xsl:if
						test="name()='tp:WSSenderBinding' or name()='tp:WSReceiverBinding' or name()='ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]/tp:WSSenderBinding' or name()='ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]/tp:WSReceiverBinding'">
						<tr class="changediv listSubSection{$numParty}6" style="display:none "
							title="">
							<!-- Web Services Binding  -->
							<td class="dati" align="center">Web Services Binding</td>
						</tr>
						<tr class="listSubSection{$numParty}6" style="display:none " title="">
							<!-- Binding Role -->
							<td class="dati" colspan="2">Binding Role: </td>
							<xsl:choose>
								<xsl:when test="name()='tp:WSSenderBinding'">
									<td class="border black">Sender</td>
									<td class="border black">Receiver</td>
								</xsl:when>
								<xsl:otherwise>
									<td class="border black">Receiver</td>
									<td class="border black">Sender</td>
								</xsl:otherwise>
							</xsl:choose>
						</tr>

						<tr class="listSubSection{$numParty}6" style="display:none " title="">
							<!-- SOAP Version -->
							<td class="dati" colspan="2">SOAP Version: </td>
							<td class="border black">
								<xsl:value-of select="@version"/>
							</td>
							<td class="border black">
								<xsl:value-of
									select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//@version"
								/>
							</td>
						</tr>
						<xsl:if
							test="tp:WSDLOperation or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:WSDLOperation">
							<tr class="listSubSection{$numParty}6" style="display:none " title="">
								<!-- WSDL Version -->
								<td class="dati" colspan="2">WSDL Version: </td>
								<td class="border black">
									<xsl:value-of select="tp:WSDLOperation/@version"/>
								</td>
								<td class="border black">
									<xsl:value-of
										select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:WSDLOperation/@version"
									/>
								</td>
							</tr>
						</xsl:if>
						<xsl:if
							test="//wsdl:definitions or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:WSDLOperation/wsdl:definitions">
							<tr class="listSubSection{$numParty}6" style="display:none " title="">
								<!-- WSDL Definition -->
								<td class="dati" colspan="2">WSDL Definition: </td>
								<td class="border black">
									<em>Name: </em>
									<xsl:value-of select="//wsdl:definitions/@name"/>
									<br/>
									<em>Namespace: </em>
									<xsl:value-of select="//wsdl:definitions/@targetNamespace"/>
								</td>
								<td class="border black">
									<em>Name: </em>
									<xsl:value-of
										select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:WSDLOperation/wsdl:definitions/@name"/>
									<br/>
									<em>Namespace: </em>
									<xsl:value-of
										select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:WSDLOperation/wsdl:definitions/@targetNamespace"
									/>
								</td>
							</tr>
						</xsl:if>
						<xsl:if
							test="//wsdl:types/text()!=null and ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:WSDLOperation//wsdl:types/text()!=null">
							<tr class="listSubSection{$numParty}6" style="display:none " title="">
								<!-- WSDL Type -->
								<td class="dati" colspan="2">WSDL Type: </td>
								<td class="border black">
									<xsl:value-of select="//wsdl:types"/>
								</td>
								<td class="border black">
									<xsl:value-of
										select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:WSDLOperation//wsdl:types"
									/>
								</td>
							</tr>
						</xsl:if>
						<xsl:if
							test="//wsdl:message or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:WSDLOperation//wsdl:message">
							<tr class="listSubSection{$numParty}6" style="display:none " title="">
								<!-- WSDL Message -->
								<td class="dati" colspan="2">WSDL Message: </td>
								<td class="border black">
									<em>Name: </em>
									<xsl:value-of select="//wsdl:message/@name"/>
									<br/>
									<em>Part Name: </em>
									<xsl:value-of select="//wsdl:message/wsdl:part/@name"/>
								</td>
								<td class="border black">
									<em>Name: </em>
									<xsl:value-of
										select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:WSDLOperation//wsdl:message/@name"/>
									<br/>
									<em>Part Name: </em>
									<xsl:value-of
										select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:WSDLOperation//wsdl:part/@name"
									/>
								</td>
							</tr>
						</xsl:if>
						<xsl:if
							test="//wsdl:portType or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:WSDLOperation//wsdl:portType">
							<tr class="listSubSection{$numParty}6" style="display:none " title="">
								<!-- WSDL Port Type -->
								<td class="dati" colspan="2">WSDL Port Type: </td>
								<td class="border black">
									<em>Name: </em>
									<xsl:value-of select="//wsdl:portType/@name"/>
									<br/>
									<em>Operation Name: </em>
									<xsl:value-of select="//wsdl:portType/wsdl:operation/@name"/>
									<br/>
									<em>Input Message: </em>
									<xsl:value-of
										select="//wsdl:portType/wsdl:operation/wsdl:input/@message"
									/>
								</td>
								<td class="border black">
									<em>Name: </em>
									<xsl:value-of
										select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:WSDLOperation//wsdl:portType/@name"/>
									<br/>
									<em>Operation Name: </em>
									<xsl:value-of
										select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:WSDLOperation//wsdl:operation/@name"/>
									<br/>
									<em>Input Message: </em>
									<xsl:value-of
										select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:WSDLOperation//wsdl:input/@message"
									/>
								</td>
							</tr>
						</xsl:if>

					</xsl:if>
				</xsl:for-each>
				<xsl:if
					test="//tp:Retries or //tp:RetryInterval or //tp:MessageOrderSemantics or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:Retries or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:RetryInterval or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:MessageOrderSemantics">
					<tr class="changediv listSubSection6" style="display:none "
						title="It specifies the characteristics of reliable messaging exchange.">
						<!-- Reliable Messaging -->
						<td class="dati" align="center">Reliable Messaging</td>
					</tr>
					<xsl:if
						test="//tp:Retries or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:Retries">
						<tr class="listSubSection6" style="display:none "
							title="It specifies the permitted number of retries and the interval, expressed as an XML Schema[XMLSCHEMA-2] duration, between retries of sending a reliably delivered message following a timeout waiting for the acknowledgment.">
							<!-- Retries -->
							<td class="dati" colspan="2">Retries: </td>
							<td class="border black">

								<xsl:for-each select="*">
									<xsl:choose>
										<xsl:when test="contains(name(),'Sender')">
											<em>Sender</em>: <xsl:value-of select=".//tp:Retries"/>
										</xsl:when>
										<xsl:otherwise>
											<br/><em>Receiver</em>: <xsl:value-of
												select=".//tp:Retries"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</td>
							<td class="border black">
								<xsl:for-each
									select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]/child::*">
									<xsl:choose>
										<xsl:when test="contains(name(),'Sender')">
											<em>Sender</em>: <xsl:value-of select=".//tp:Retries"/>
										</xsl:when>
										<xsl:otherwise>
											<br/><em>Receiver</em>: <xsl:value-of
												select=".//tp:Retries"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</td>
						</tr>
					</xsl:if>
					<xsl:if
						test="//tp:RetryInterval or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:RetryInterval">
						<tr class="listSubSection6" style="display:none "
							title="The purpose of the Retry Interval is to improve the likelihood of success on retry by deferring the retry until any temporary conditions that caused the error might be corrected.">
							<!-- RetryInterval -->
							<td class="dati" colspan="2">Retry Interval: </td>
							<td class="border black">
								<xsl:for-each select="*">
									<xsl:choose>
										<xsl:when test="contains(name(),'Sender')">
											<em>Sender</em>: <xsl:value-of
												select=".//tp:RetryInterval"/>
										</xsl:when>
										<xsl:otherwise>
											<br/><em>Receiver</em>: <xsl:value-of
												select=".//tp:RetryInterval"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</td>
							<td class="border black">
								<xsl:for-each
									select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]/child::*">
									<xsl:choose>
										<xsl:when test="contains(name(),'Sender')">
											<em>Sender</em>: <xsl:value-of
												select=".//tp:RetryInterval"/>
										</xsl:when>
										<xsl:otherwise>
											<br/><em>Receiver</em>: <xsl:value-of
												select=".//tp:RetryInterval"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</td>
						</tr>
					</xsl:if>
					<xsl:if
						test="//tp:MessageOrderSemantics or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:MessageOrderSemantics">
						<tr class="listSubSection6" style="display:none "
							title="It specifies if the order of sending (and)or receiving messages is guaranteed or not.">
							<!-- MessageOrderSemantics -->
							<td class="dati" colspan="2">Message Order Semantics: </td>
							<td class="border black">
								<xsl:for-each select="*">
									<xsl:choose>
										<xsl:when test="contains(name(),'Sender')">
											<em>Sender</em>: <xsl:value-of
												select=".//tp:MessageOrderSemantics"/>
										</xsl:when>
										<xsl:otherwise>
											<br/><em>Receiver</em>: <xsl:value-of
												select=".//tp:MessageOrderSemantics"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</td>
							<td class="border black">
								<xsl:for-each
									select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]/child::*">
									<xsl:choose>
										<xsl:when test="contains(name(),'Sender')">
											<em>Sender</em>: <xsl:value-of
												select=".//tp:MessageOrderSemantics"/>
										</xsl:when>
										<xsl:otherwise>
											<br/><em>Receiver</em>: <xsl:value-of
												select=".//tp:MessageOrderSemantics"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</td>
						</tr>
					</xsl:if>
				</xsl:if>

				<xsl:if
					test="//tp:NonRepudiationProtocol or //tp:HashFunction or //tp:SignatureAlgorithm or //tp:SigningCertificateRef or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:NonRepudiationProtocol or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:HashFunction or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:SignatureAlgorithm or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:SigningCertificateRef">
					<tr class="changediv listSubSection6" style="display:none "
						title="It conveys the message sender’s requirements and certificate for non-repudiation. Non-repudiation both proves who sent a message and prevents later repudiation of the contents of the message. Non-repudiation is based on signing the message using XML Digital Signature[XMLDSIG].">
						<!-- NonRepudiation-->
						<td class="dati" align="center">Non Repudiation</td>
					</tr>
					<xsl:if
						test="//tp:NonRepudiationProtocol or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:NonRepudiationProtocol">
						<tr class="listSubSection6" style="display:none "
							title="It identifies the technology that will be used to digitally sign a message.">
							<!-- NonRepudiationProtocol -->
							<td class="dati" colspan="2">Protocol: </td>
							<td class="border black">
								<xsl:for-each select="*">
									<xsl:choose>
										<xsl:when test="contains(name(),'Sender')"><em> Sender</em>:
												<xsl:value-of select=".//tp:NonRepudiationProtocol"
											/>
										</xsl:when>
										<xsl:otherwise>
											<br/><em>Receiver</em>: <xsl:value-of
												select=".//tp:NonRepudiationProtocol"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</td>
							<td class="border black">
								<xsl:for-each
									select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]/child::*">
									<xsl:choose>
										<xsl:when test="contains(name(),'Sender')">
											<em>Sender</em>: <xsl:value-of
												select=".//tp:NonRepudiationProtocol"/>
										</xsl:when>
										<xsl:otherwise>
											<br/><em>Receiver</em>: <xsl:value-of
												select=".//tp:NonRepudiationProtocol"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</td>
						</tr>
					</xsl:if>
					<xsl:if
						test="//tp:HashFunction or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:HashFunction">
						<tr class="listSubSection6" style="display:none "
							title="It identifies the algorithm that is used to compute the digest of the message.">
							<!-- HashFunction -->
							<td class="dati" colspan="2">Hash Function: </td>
							<td class="border black">
								<xsl:for-each select="*">
									<xsl:choose>
										<xsl:when test="contains(name(),'Sender')">
											<em>Sender</em>: <xsl:value-of
												select=".//tp:HashFunction"/>
										</xsl:when>
										<xsl:otherwise>
											<br/><em>Receiver</em>: <xsl:value-of
												select=".//tp:HashFunction"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</td>
							<td class="border black">
								<xsl:for-each
									select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]/child::*">
									<xsl:choose>
										<xsl:when test="contains(name(),'Sender')">
											<em>Sender</em>: <xsl:value-of
												select=".//tp:HashFunction"/>
										</xsl:when>
										<xsl:otherwise>
											<br/><em>Receiver</em>: <xsl:value-of
												select=".//tp:HashFunction"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</td>
						</tr>
					</xsl:if>
					<xsl:if
						test="//tp:SignatureAlgorithm or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:SignatureAlgorithm">
						<tr class="listSubSection6" style="display:none "
							title="It identifies the algorithm that is used to compute the value of the digital signature.">
							<!-- SignatureAlgorithm -->
							<td class="dati" colspan="2">Signature Algorithm: </td>
							<td class="border black">
								<xsl:for-each select="*">
									<xsl:choose>
										<xsl:when test="contains(name(),'Sender')">
											<em>Sender</em>: <xsl:value-of
												select=".//tp:SignatureAlgorithm"/>
										</xsl:when>
										<xsl:otherwise>
											<br/><em>Receiver</em>: <xsl:value-of
												select=".//tp:SignatureAlgorithm"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</td>
							<td class="border black">
								<xsl:for-each
									select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]/child::*">
									<xsl:choose>
										<xsl:when test="contains(name(),'Sender')">
											<em>Sender</em>: <xsl:value-of
												select=".//tp:SignatureAlgorithm"/>
										</xsl:when>
										<xsl:otherwise>
											<br/><em>Receiver</em>: <xsl:value-of
												select=".//tp:SignatureAlgorithm"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</td>
						</tr>
					</xsl:if>
					<xsl:if
						test="//tp:SigningCertificateRef or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:SigningCertificateRef">
						<tr class="listSubSection6" style="display:none "
							title="It identifies the certificate the used for signing messages. It refers to the certificate element that has the matching ID attribute value.">
							<!-- SigningCertificate -->
							<td class="dati" colspan="2">Signing Certificate: </td>
							<td class="border black">
								<em>Sender</em>: <a href="#{//tp:SigningCertificateRef/@certId}"
									onclick="ApriAncora('listSubSubSection71','listSubSection71'); ApriAncora('listSubSubSection72','listSubSection72');">
									<xsl:value-of select="//tp:SigningCertificateRef/@certId"/>
								</a>
							</td>
							<td class="border black">
								<em>Sender</em>: <a
									href="#{ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:SigningCertificateRef/@certId}"
									onclick="ApriAncora('listSubSubSection71','listSubSection71');ApriAncora('listSubSubSection72','listSubSection72');">
									<xsl:value-of
										select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:SigningCertificateRef/@certId"
									/>
								</a>
							</td>
						</tr>
					</xsl:if>
				</xsl:if>

				<xsl:if
					test="//tp:DigitalEnvelopeProtocol or //tp:EncryptionAlgorithm or  ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:DigitalEnvelopeProtocol or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:EncryptionAlgorithm">
					<tr class="changediv listSubSection6" style="display:none "
						title="It provides the requirements for message encryption using the [DIGENV] digital-envelope method, which is a procedure in which the message is encrypted by symmetric encryption (shared secret key) and the secret key is sent to the message recipient encrypted with the recipient's public key.">
						<!-- Digital Envelope-->
						<td class="dati" align="center">Digital Envelope</td>
					</tr>
					<xsl:if
						test="//tp:DigitalEnvelopeProtocol or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:DigitalEnvelopeProtocol">
						<tr class="listSubSection6" style="display:none "
							title="It identifies the message encryption protocol to be used.">
							<!-- DigitalEnvelopeProtocol -->
							<td class="dati" colspan="2">Protocol: </td>
							<td class="border black">
								<xsl:for-each select="*">
									<xsl:choose>
										<xsl:when test="contains(name(),'Sender')">
											<em>Sender</em>: <xsl:value-of
												select=".//tp:DigitalEnvelopeProtocol"/>
										</xsl:when>
										<xsl:otherwise>
											<br/><em>Receiver</em>: <xsl:value-of
												select=".//tp:DigitalEnvelopeProtocol"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</td>
							<td class="border black">
								<xsl:for-each
									select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]/child::*">
									<xsl:choose>
										<xsl:when test="contains(name(),'Sender')">
											<em>Sender</em>: <xsl:value-of
												select=".//tp:DigitalEnvelopeProtocol"/>
										</xsl:when>
										<xsl:otherwise>
											<br/><em>Receiver</em>: <xsl:value-of
												select=".//tp:DigitalEnvelopeProtocol"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</td>
						</tr>
					</xsl:if>
					<xsl:if
						test="//tp:EncryptionAlgorithm or ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]//tp:EncryptionAlgorithm">
						<tr class="listSubSection6" style="display:none "
							title="It identifies the encryption algorithm to be used.">
							<!-- EncryptionAlgorithm -->
							<td class="dati" colspan="2">Encryption Algorithm: </td>
							<td class="border black">
								<xsl:for-each select="*">
									<xsl:choose>
										<xsl:when test="contains(name(),'Sender')">
											<em>Sender</em>: <xsl:value-of
												select=".//tp:EncryptionAlgorithm"/>
										</xsl:when>
										<xsl:otherwise>
											<br/><em>Receiver</em>: <xsl:value-of
												select=".//tp:EncryptionAlgorithm"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</td>
							<td class="border black">
								<xsl:for-each
									select="ancestor::tp:CollaborationProtocolAgreement/tp:PartyInfo[2]/tp:DocExchange[position()=$numDoc]/child::*">
									<xsl:choose>
										<xsl:when test="contains(name(),'Sender')">
											<em>Sender</em>: <xsl:value-of
												select=".//tp:EncryptionAlgorithm"/>
										</xsl:when>
										<xsl:otherwise>
											<br/><em>Receiver</em>: <xsl:value-of
												select=".//tp:EncryptionAlgorithm"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</td>
						</tr>
					</xsl:if>
				</xsl:if>
			</xsl:when>

			<!-- Se il documento è un CPP -->
			<xsl:otherwise>
				<xsl:for-each select="*">
					<xsl:if test="contains(name(),'Sender') or contains(name(),'Receiver')">
						<tr class="changediv listSubSection{$numParty}6" style="display:none "
							title="">
							<!-- Web Services Binding  -->
							<td class="dati" align="center">Web Services Binding</td>
						</tr>
						<tr class="listSubSection{$numParty}6" style="display:none " title="">
							<!-- Binding Role -->
							<td class="dati" colspan="2">Binding Role: </td>
							<td class="border black">
								<xsl:choose>
									<xsl:when test="contains(name(),'Sender')"> Sender </xsl:when>
									<xsl:otherwise> Receiver </xsl:otherwise>
								</xsl:choose>
							</td>
						</tr>
						<tr class="listSubSection{$numParty}6" style="display:none " title="">
							<!-- SOAP Version -->
							<td class="dati" colspan="2">SOAP Version: </td>
							<td class="border black">
								<xsl:value-of select="@version"/>
							</td>
						</tr>
						<xsl:if test="tp:WSDLOperation">
							<tr class="listSubSection{$numParty}6" style="display:none " title="">
								<!-- WSDL Version -->
								<td class="dati" colspan="2">WSDL Version: </td>
								<td class="border black">
									<xsl:value-of select="tp:WSDLOperation/@version"/>
								</td>
							</tr>
						</xsl:if>
						<xsl:if test="//wsdl:definitions">
							<tr class="listSubSection{$numParty}6" style="display:none " title="">
								<!-- WSDL Definition -->
								<td class="dati" colspan="2">WSDL Definition: </td>
								<td class="border black">
									<em>Name: </em>
									<xsl:value-of select="//wsdl:definitions/@name"/>
									<br/>
									<em>Namespace: </em>
									<xsl:value-of select="//@targetNamespace"/>
								</td>
							</tr>
							<xsl:if test="//wsdl:types/text()">
								<tr class="listSubSection{$numParty}6" style="display:none "
									title="">
									<!-- WSDL Type -->
									<td class="dati" colspan="2">WSDL Type: </td>
									<td class="border black">
										<xsl:value-of select="//wsdl:types"/>
									</td>
								</tr>
							</xsl:if>
							<xsl:if test="//wsdl:message">
								<tr class="listSubSection{$numParty}6" style="display:none "
									title="">
									<!-- WSDL Message -->
									<td class="dati" colspan="2">WSDL Message: </td>
									<td class="border black">
										<em>Name: </em>
										<xsl:value-of select="//wsdl:message/@name"/>
										<br/>
										<em>Part Name: </em>
										<xsl:value-of select="//wsdl:message/wsdl:part/@name"/>
									</td>
								</tr>
							</xsl:if>
							<xsl:if test="//wsdl:portType">
								<tr class="listSubSection{$numParty}6" style="display:none "
									title="">
									<!-- WSDL Port Type -->
									<td class="dati" colspan="2">WSDL Port Type: </td>
									<td class="border black">
										<em>Name: </em>
										<xsl:value-of select="//wsdl:portType/@name"/>
										<br/>
										<em>Operation Name: </em>
										<xsl:value-of select="//wsdl:portType/wsdl:operation/@name"/>
										<br/>
										<em>Input Message: </em>
										<xsl:value-of
											select="//wsdl:portType/wsdl:operation/wsdl:input/@message"
										/>
									</td>
								</tr>
							</xsl:if>
						</xsl:if>
					</xsl:if>
				</xsl:for-each>

				<xsl:if test="//tp:Retries or //tp:RetryInterval or //tp:MessageOrderSemantics">
					<tr class="changediv listSubSection{$numParty}6" style="display:none "
						title="It specifies the characteristics of reliable messaging exchange.">
						<!-- Reliable Messaging -->
						<td class="dati" align="center">Reliable Messaging</td>
					</tr>
					<tr class="listSubSection{$numParty}6" style="display:none "
						title="It specifies the permitted number of retries and the interval, expressed as an XML Schema[XMLSCHEMA-2] duration, between retries of sending a reliably delivered message following a timeout waiting for the acknowledgment.">
						<!-- Retries -->
						<td class="dati" colspan="2">Retries: </td>
						<xsl:for-each select="*">
							<td class="border black">
								<xsl:value-of select="//tp:Retries"/>
							</td>
						</xsl:for-each>
					</tr>

					<tr class="listSubSection6" style="display:none "
						title="The purpose of the Retry Interval is to improve the likelihood of success on retry by deferring the retry until any temporary conditions that caused the error might be corrected.">
						<!-- RetryInterval -->
						<td class="dati" colspan="2">Retry Interval: </td>
						<xsl:for-each select="*">
							<td class="border black">
								<xsl:value-of select=".//tp:RetryInterval"/>
							</td>
						</xsl:for-each>
					</tr>

					<tr class="listSubSection6" style="display:none "
						title="It specifies if the order of sending (and)or receiving messages is guaranteed or not.">
						<!-- MessageOrderSemantics -->
						<td class="dati" colspan="2">Message Order Semantics: </td>
						<xsl:for-each select="*">
							<td class="border black">
								<xsl:value-of select=".//tp:MessageOrderSemantics"/>
							</td>
						</xsl:for-each>
					</tr>
				</xsl:if>

				<xsl:if
					test="//tp:NonRepudiationProtocol or  tp:HashFunction or //tp:SignatureAlgorithm or //tp:SigningCertificateRef">
					<tr class="changediv listSubSection6" style="display:none "
						title="It conveys the message sender’s requirements and certificate for non-repudiation. Non-repudiation both proves who sent a message and prevents later repudiation of the contents of the message. Non-repudiation is based on signing the message using XML Digital Signature[XMLDSIG].">
						<!-- NonRepudiation-->
						<td class="dati" align="center">Non Repudiation</td>
					</tr>
					<tr class="listSubSection6" style="display:none "
						title="It identifies the technology that will be used to digitally sign a message.">
						<!-- NonRepudiationProtocol -->
						<td class="dati" colspan="2">Protocol: </td>
						<xsl:for-each select="*">
							<td class="border black">
								<xsl:value-of select=".//tp:NonRepudiationProtocol"/>
							</td>
						</xsl:for-each>
					</tr>

					<tr class="listSubSection6" style="display:none "
						title="It identifies the algorithm that is used to compute the digest of the message.">
						<!-- HashFunction -->
						<td class="dati" colspan="2">Hash Function: </td>
						<xsl:for-each select="*">
							<td class="border black">
								<xsl:value-of select=".//tp:HashFunction"/>
							</td>
						</xsl:for-each>
					</tr>

					<tr class="listSubSection6" style="display:none "
						title="It identifies the algorithm that is used to compute the value of the digital signature.">
						<!-- SignatureAlgorithm -->
						<td class="dati" colspan="2">Signature Algorithm: </td>
						<xsl:for-each select="*">
							<td class="border black">
								<xsl:value-of select=".//tp:SignatureAlgorithm"/>
							</td>
						</xsl:for-each>
					</tr>

					<tr class="listSubSection6" style="display:none "
						title="It identifies the certificate the used for signing messages. It refers to the certificate element that has the matching ID attribute value.">
						<!-- SigningCertificate -->
						<td class="dati" colspan="2">Signing Certificate: </td>
						<xsl:for-each select="*">
							<td class="border black">
								<a href="#{//tp:SigningCertificateRef/@certId}">
									<xsl:attribute name="onClick">
											ApriAncora('listSubSection<xsl:value-of
											select="$numParty"/>7','listParty<xsl:value-of
											select="$numParty"/>7'); </xsl:attribute>
									<xsl:value-of select="//tp:SigningCertificateRef/@certId"/>
								</a>
							</td>
						</xsl:for-each>
					</tr>
				</xsl:if>

				<xsl:if test="//tp:DigitalEnvelopeProtocol or tp:EncryptionAlgorithm">
					<tr class="changediv listSubSection6" style="display:none "
						title="It provides the requirements for message encryption using the [DIGENV] digital-envelope method, which is a procedure in which the message is encrypted by symmetric encryption (shared secret key) and the secret key is sent to the message recipient encrypted with the recipient's public key.">
						<!-- Digital Envelope-->
						<td class="dati" align="center">Digital Envelope</td>
					</tr>
					<tr class="listSubSection6" style="display:none "
						title="It identifies the message encryption protocol to be used.">
						<!-- DigitalEnvelopeProtocol -->
						<td class="dati" colspan="2">Protocol: </td>
						<xsl:for-each select="*">
							<td class="border black">
								<xsl:value-of select=".//tp:DigitalEnvelopeProtocol"/>
							</td>
						</xsl:for-each>
					</tr>

					<tr class="listSubSection6" style="display:none "
						title="It identifies the encryption algorithm to be used.">
						<!-- EncryptionAlgorithm -->
						<td class="dati" colspan="2">Encryption Algorithm: </td>
						<xsl:for-each select="*">
							<td class="border black">
								<xsl:value-of select=".//tp:EncryptionAlgorithm"/>
							</td>
						</xsl:for-each>
					</tr>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<!-- sviluppo certificates cpp/cpa -->
	<!-- Template Certificate, visualizza le informazioni relaive ai certificati che vengono emessi dalle parti. -->
	<xsl:template match="tp:Certificate" name="Certificates">
		<xsl:param name="numParty"/>
		<xsl:choose>
			<!-- Se il documento è un CPP. -->
			<xsl:when test="ancestor::tp:CollaborationProtocolProfile">
				<tr class="listSubSection{$numParty}7" style="display:none ">
					<td class="dati" colspan="2">Certificate ID : </td>
					<td colspan="2" class="border black">
						<a name="{@certId}">
							<xsl:value-of select="@certId"/>
						</a>
					</td>
				</tr>
				<xsl:for-each select="descendant::*">
					<xsl:choose>
						<xsl:when test="name()='ds:KeyName'">
							<tr class="listSubSection{$numParty}7" style="display:none ">
								<td class="dati" colspan="2">Key Name: </td>
								<td colspan="2" class="border black">
									<xsl:value-of select="."/>
								</td>
							</tr>
						</xsl:when>
						<xsl:when test="contains(name(),'Data')">
							<tr class="listSubSection{$numParty}7" style="display:none ">
								<td class="dati" colspan="2">Certificate Type: </td>
								<td colspan="2" class="border black">
									<xsl:value-of
										select="substring-before(substring-after(name(),':'),'Data')"
									/>
								</td>
							</tr>
						</xsl:when>
						<xsl:when test="contains(name(),'Certificate')">
							<tr class="listSubSection{$numParty}7" style="display:none ">
								<td class="dati" colspan="2">Certificate: </td>
								<td colspan="2" class="border black">
									<xsl:value-of select="."/>
								</td>
							</tr>
						</xsl:when>
						<xsl:when test="contains(name(),'KeyValue') and name()!='ds:KeyValue'">
							<tr class="listSubSection{$numParty}7" style="display:none ">
								<td class="dati" colspan="2">Public Key Algorithm: </td>
								<td colspan="2" class="border black">
									<xsl:value-of
										select="substring-before(substring-after(name(),':'),'KeyValue')"
									/>
								</td>
							</tr>
						</xsl:when>
						<xsl:when test="name()='ds:Modulus' and ds:Modulus/text()">
							<tr class="listSubSection{$numParty}7" style="display:none ">
								<td class="dati" colspan="2">Modulus: </td>
								<td colspan="2" class="border black">
									<xsl:value-of select="."/>
								</td>
							</tr>
						</xsl:when>
						<xsl:when test="name()='ds:Exponent' and ds:Exponent/text()">
							<tr class="listSubSection{$numParty}7" style="display:none ">
								<td class="dati" colspan="2">Exponent: </td>
								<td colspan="2" class="border black">
									<xsl:value-of select="."/>
								</td>
							</tr>
						</xsl:when>
					</xsl:choose>
				</xsl:for-each>
				<tr class="divisorio listSubSection{$numParty}7" style="display:none;">
					<xsl:if test="position() != last()">
						<td colspan="4">
							<hr/>
						</td>
					</xsl:if>
				</tr>
			</xsl:when>
			<!-- Se il documento è un CPA. -->
			<xsl:otherwise>
				<tr class="sottosottosezione listSubSection7{$numParty} pare"
					id="listSubSection7{$numParty}" style="display:none "
					title="This subsection defines all the one party's certificates.">
					<xsl:attribute name="onClick"> ApriChiudiClasse('listSubSubSection7<xsl:value-of
							select="$numParty"/>','listSubSection7<xsl:value-of select="$numParty"
						/>'); </xsl:attribute>
					<td colspan="4">Certificates Party <xsl:value-of select="./@partyName"/>
						<xsl:if test="count(current()[$numParty]/tp:Certificate) > 1 "> (Total
								Number:<xsl:value-of
								select="count(current()[$numParty]/tp:Certificate)"/>)</xsl:if>
					</td>
				</tr>
				<xsl:for-each select="current()[$numParty]/tp:Certificate">
					<tr class="listSubSubSection7{$numParty}" style="display:none ">

						<td class="dati" colspan="2">Certificate ID : </td>
						<td colspan="2" class="border black">
							<a name="{@certId}">
								<xsl:value-of select="@certId"/>
							</a>
						</td>
					</tr>
					<xsl:for-each select="descendant::*">
						<xsl:choose>
							<xsl:when test="name()='ds:KeyName'">
								<tr class="listSubSubSection7{$numParty}" style="display:none ">
									<td class="dati" colspan="2">Key Name: </td>
									<td colspan="2" class="border black">
										<xsl:value-of select="."/>
									</td>
								</tr>
							</xsl:when>
							<xsl:when test="contains(name(),'Data')">
								<tr class="listSubSubSection7{$numParty}" style="display:none ">
									<td class="dati" colspan="2">Certificate Type: </td>
									<td colspan="2" class="border black">
										<xsl:value-of
											select="substring-before(substring-after(name(),':'),'Data')"
										/>
									</td>
								</tr>
							</xsl:when>
							<xsl:when test="contains(name(),'Certificate')">
								<tr class="listSubSubSection7{$numParty}" style="display:none ">
									<td class="dati" colspan="2">Certificate: </td>
									<td colspan="2" class="border black">
										<xsl:value-of select="."/>
									</td>
								</tr>
							</xsl:when>
							<xsl:when test="contains(name(),'KeyValue') and name()!='ds:KeyValue'">
								<tr class="listSubSubSection7{$numParty}" style="display:none ">
									<td class="dati" colspan="2">Public Key Algorithm: </td>
									<td colspan="2" class="border black">
										<xsl:value-of
											select="substring-before(substring-after(name(),':'),'KeyValue')"
										/>
									</td>
								</tr>
							</xsl:when>
							<xsl:when test="name()='ds:Modulus' and ds:Modulus/text()">
								<tr class="listSubSubSection7{$numParty}" style="display:none ">
									<td class="dati" colspan="2">Modulus: </td>
									<td colspan="2" class="border black">
										<xsl:value-of select="."/>
									</td>
								</tr>
							</xsl:when>
							<xsl:when test="name()='ds:Exponent' and ds:Exponent/text()">
								<tr class="listSubSubSection7{$numParty}" style="display:none ">
									<td class="dati" colspan="2">Exponent: </td>
									<td colspan="2" class="border black">
										<xsl:value-of select="."/>
									</td>
								</tr>
							</xsl:when>
						</xsl:choose>
					</xsl:for-each>
					<tr class="divisorio listSubSubSection7{$numParty}" style="display:none">
						<xsl:if test="position() != last()">
							<td colspan="4">
								<hr/>
							</td>
						</xsl:if>
					</tr>
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--********************* FINE Sezione PARTY INFORMATION ************************** -->

	<!--********************* INIZIO Sezione PACKING ************************** -->
	<!-- sviluppo message packaging cpp/cpa-->
	<!-- Template Packaging, consente di visualizzare informazioni relative all'impacchettamento dei messaggi, sia nel caso di CPP che di CPA. -->
	<xsl:template match="tp:Packaging">
		<tr class="listSection3" style="display:none;">
			<td class="dati" colspan="2">Packaging ID:</td>
			<td class="border black" colspan="2">
				<a name="{@id}">
					<xsl:value-of select="@id"/>
				</a>
			</td>
		</tr>
		<!-- Per tutti i figli del nodo tp:Packaging. -->
		<xsl:apply-templates/>

		<tr class="divisorio listSection3" style="display:none;">
			<xsl:if test="position() != last()">
				<td colspan="4">
					<hr/>
				</td>
			</xsl:if>
		</tr>
	</xsl:template>

	<!-- sviluppo compositeList cpp/cpa-->
	<!-- Template che viene richiamato dal packaging, in quanto figlio diretto. -->
	<xsl:template match="tp:CompositeList | tp:Constituent">
		<xsl:choose>
			<xsl:when test="name(.)='tp:CompositeList'">
				<xsl:apply-templates/>
			</xsl:when>
			<xsl:otherwise>
				<tr class="listSection3" style="display:none;">
					<td class="dati" colspan="2"><xsl:value-of select="substring-after(name(.),':')"
						/>:</td>
					<td class="border black" colspan="2">

						<p><span class="changediv">Constituent ID</span>: <xsl:value-of
								select="@idref"/><br/>
							<span class="changediv">Constituent Location</span>: <!--recupero la location dalla simple part -->
							<xsl:variable name="refSimplePart" select="@idref"/>
							<xsl:apply-templates select="//tp:SimplePart[@id=$refSimplePart]"/>
						</p>
					</td>
				</tr>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<!-- Template che visualizza i dati relativi alle tipologie di packaging che si possono avere. -->
	<xsl:template match="tp:Composite | tp:Encapsulation">
		<tr class="listSection3" style="display:none;">
			<td class="dati" colspan="2">
				<xsl:value-of select="substring-after(name(.),':')"/>
			</td>
			<td class="border black" colspan="2">
				<p><span class="changediv">ID</span>: <xsl:value-of select="@id"/><br/>
					<span class="changediv">MIME Type</span>: <xsl:value-of select="@mimetype"/><br/>
					<span class="changediv">MIME paramenters</span>: <xsl:value-of
						select="@mimeparameters"/></p>

				<xsl:for-each select="tp:Constituent">
					<p><span class="changediv">Constituent ID</span>: <xsl:value-of select="@idref"/><br/>
						<span class="changediv">Constituent Location</span>: <!--recupero la location dalla simple part -->
						<xsl:variable name="refSimplePart" select="@idref"/>
						<xsl:apply-templates select="//tp:SimplePart[@id=$refSimplePart]"/>
					</p>
				</xsl:for-each>
			</td>
		</tr>
	</xsl:template>

	<!-- Template SimplePart che fornisce una lista di componenti relativi al packaging.-->
	<xsl:template match="tp:SimplePart">
		<xsl:choose>
			<xsl:when test="tp:NamespaceSupported/@location">
				<a href="{.}"><xsl:value-of select="."/></a>
			</xsl:when>
			<xsl:otherwise> None </xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!--*********************FINE Sezione PACKING ************************** -->

</xsl:stylesheet>

<!-- Stylus Studio meta-information - (c) 2004-2007. Progress Software Corporation. All rights reserved.
<metaInformation>
<scenarios ><scenario default="yes" name="CPA" userelativepaths="yes" externalpreview="yes" url="..\cpa\CPA_de-22222222222_it-11111111111_2007-11-08.xml" htmlbaseurl="" outputurl="..\xhtml\CPA_de-22222222222_it-11111111111_2007-11-08.htm" processortype="saxon8" useresolver="yes" profilemode="0" profiledepth="" profilelength="" urlprofilexml="" commandline="" additionalpath="" additionalclasspath="" postprocessortype="none" postprocesscommandline="" postprocessadditionalpath="" postprocessgeneratedext="" validateoutput="no" validator="internal" customvalidator="" ><advancedProp name="sInitialMode" value=""/><advancedProp name="bXsltOneIsOkay" value="true"/><advancedProp name="bSchemaAware" value="true"/><advancedProp name="bXml11" value="false"/><advancedProp name="iValidation" value="0"/><advancedProp name="bExtensions" value="true"/><advancedProp name="iWhitespace" value="0"/><advancedProp name="sInitialTemplate" value=""/><advancedProp name="bTinyTree" value="true"/><advancedProp name="bWarnings" value="true"/><advancedProp name="bUseDTD" value="false"/><advancedProp name="iErrorHandling" value="fatal"/></scenario></scenarios><MapperMetaTag><MapperInfo srcSchemaPathIsRelative="yes" srcSchemaInterpretAsXML="no" destSchemaPath="" destSchemaRoot="" destSchemaPathIsRelative="yes" destSchemaInterpretAsXML="no"/><MapperBlockPosition></MapperBlockPosition><TemplateContext></TemplateContext><MapperFilter side="source"></MapperFilter></MapperMetaTag>
</metaInformation>
-->